# ===================================================================================================
#                           _  __     _ _
#                          | |/ /__ _| | |_ _  _ _ _ __ _
#                          | ' </ _` | |  _| || | '_/ _` |
#                          |_|\_\__,_|_|\__|\_,_|_| \__,_|
#
# This file is part of the Kaltura Collaborative Media Suite which allows users
# to do with audio, video, and animation what Wiki platforms allow them to do with
# text.
#
# Copyright (C) 2006-2023  Kaltura Inc.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http:#www.gnu.org/licenses/>.
#
# @ignore
# ===================================================================================================
from typing import List, IO, Any
from .Core import *
from KalturaClient.Base import KalturaObjectBase, KalturaServiceBase

class KalturaAuditTrailChangeXmlNodeType(object):
    CHANGED = 1
    ADDED = 2
    REMOVED = 3

    def __init__(self, value: int): ...

    def getValue(self) -> int: ...

class KalturaAuditTrailContext(object):
    CLIENT = -1
    SCRIPT = 0
    PS2 = 1
    API_V3 = 2

    def __init__(self, value: int): ...

    def getValue(self) -> int: ...

class KalturaAuditTrailFileSyncType(object):
    FILE = 1
    LINK = 2
    URL = 3

    def __init__(self, value: int): ...

    def getValue(self) -> int: ...

class KalturaAuditTrailStatus(object):
    PENDING = 1
    READY = 2
    FAILED = 3

    def __init__(self, value: int): ...

    def getValue(self) -> int: ...

class KalturaAuditTrailAction(object):
    CHANGED = "CHANGED"
    CONTENT_VIEWED = "CONTENT_VIEWED"
    COPIED = "COPIED"
    CREATED = "CREATED"
    DELETED = "DELETED"
    FILE_SYNC_CREATED = "FILE_SYNC_CREATED"
    RELATION_ADDED = "RELATION_ADDED"
    RELATION_REMOVED = "RELATION_REMOVED"
    VIEWED = "VIEWED"

    def __init__(self, value: str): ...

    def getValue(self) -> str: ...

class KalturaAuditTrailObjectType(object):
    BATCH_JOB = "BatchJob"
    EMAIL_INGESTION_PROFILE = "EmailIngestionProfile"
    FILE_SYNC = "FileSync"
    KSHOW_KUSER = "KshowKuser"
    METADATA = "Metadata"
    METADATA_PROFILE = "MetadataProfile"
    PARTNER = "Partner"
    PERMISSION = "Permission"
    REACH_PROFILE = "ReachProfile"
    UPLOAD_TOKEN = "UploadToken"
    USER_LOGIN_DATA = "UserLoginData"
    USER_ROLE = "UserRole"
    ACCESS_CONTROL = "accessControl"
    CATEGORY = "category"
    CATEGORY_ENTRY = "categoryEntry"
    CONVERSION_PROFILE_2 = "conversionProfile2"
    ENTRY = "entry"
    FLAVOR_ASSET = "flavorAsset"
    FLAVOR_PARAMS = "flavorParams"
    FLAVOR_PARAMS_CONVERSION_PROFILE = "flavorParamsConversionProfile"
    FLAVOR_PARAMS_OUTPUT = "flavorParamsOutput"
    KSHOW = "kshow"
    KUSER = "kuser"
    MEDIA_INFO = "mediaInfo"
    MODERATION = "moderation"
    ROUGHCUT = "roughcutEntry"
    SYNDICATION = "syndicationFeed"
    THUMBNAIL_ASSET = "thumbAsset"
    THUMBNAIL_PARAMS = "thumbParams"
    THUMBNAIL_PARAMS_OUTPUT = "thumbParamsOutput"
    UI_CONF = "uiConf"
    WIDGET = "widget"

    def __init__(self, value: str): ...

    def getValue(self) -> str: ...

class KalturaAuditTrailOrderBy(object):
    CREATED_AT_ASC = "+createdAt"
    PARSED_AT_ASC = "+parsedAt"
    CREATED_AT_DESC = "-createdAt"
    PARSED_AT_DESC = "-parsedAt"

    def __init__(self, value: str): ...

    def getValue(self) -> str: ...

class KalturaAuditTrailInfo(KalturaObjectBase):
    def __init__(self): ...
        pass

class KalturaAuditTrail(KalturaObjectBase):
    id: int
    createdAt: int
    parsedAt: int
    status: KalturaAuditTrailStatus
    auditObjectType: KalturaAuditTrailObjectType
    objectId: str
    relatedObjectId: str
    relatedObjectType: KalturaAuditTrailObjectType
    entryId: str
    masterPartnerId: int
    partnerId: int
    requestId: str
    userId: str
    action: KalturaAuditTrailAction
    data: KalturaAuditTrailInfo
    ks: str
    context: KalturaAuditTrailContext
    entryPoint: str
    serverName: str
    ipAddress: str
    userAgent: str
    clientTag: str
    description: str
    errorDescription: str
    def __init__(self,
            id: int = NotImplemented,
            createdAt: int = NotImplemented,
            parsedAt: int = NotImplemented,
            status: KalturaAuditTrailStatus = NotImplemented,
            auditObjectType: KalturaAuditTrailObjectType = NotImplemented,
            objectId: str = NotImplemented,
            relatedObjectId: str = NotImplemented,
            relatedObjectType: KalturaAuditTrailObjectType = NotImplemented,
            entryId: str = NotImplemented,
            masterPartnerId: int = NotImplemented,
            partnerId: int = NotImplemented,
            requestId: str = NotImplemented,
            userId: str = NotImplemented,
            action: KalturaAuditTrailAction = NotImplemented,
            data: KalturaAuditTrailInfo = NotImplemented,
            ks: str = NotImplemented,
            context: KalturaAuditTrailContext = NotImplemented,
            entryPoint: str = NotImplemented,
            serverName: str = NotImplemented,
            ipAddress: str = NotImplemented,
            userAgent: str = NotImplemented,
            clientTag: str = NotImplemented,
            description: str = NotImplemented,
            errorDescription: str = NotImplemented): ...

    def getId(self) -> int: ...
    def getCreatedAt(self) -> int: ...
    def getParsedAt(self) -> int: ...
    def getStatus(self) -> KalturaAuditTrailStatus: ...
    def getAuditObjectType(self) -> KalturaAuditTrailObjectType: ...
    def setAuditObjectType(self, newAuditObjectType: KalturaAuditTrailObjectType) -> None: ...
    def getObjectId(self) -> str: ...
    def setObjectId(self, newObjectId: str) -> None: ...
    def getRelatedObjectId(self) -> str: ...
    def setRelatedObjectId(self, newRelatedObjectId: str) -> None: ...
    def getRelatedObjectType(self) -> KalturaAuditTrailObjectType: ...
    def setRelatedObjectType(self, newRelatedObjectType: KalturaAuditTrailObjectType) -> None: ...
    def getEntryId(self) -> str: ...
    def setEntryId(self, newEntryId: str) -> None: ...
    def getMasterPartnerId(self) -> int: ...
    def getPartnerId(self) -> int: ...
    def getRequestId(self) -> str: ...
    def getUserId(self) -> str: ...
    def setUserId(self, newUserId: str) -> None: ...
    def getAction(self) -> KalturaAuditTrailAction: ...
    def setAction(self, newAction: KalturaAuditTrailAction) -> None: ...
    def getData(self) -> KalturaAuditTrailInfo: ...
    def setData(self, newData: KalturaAuditTrailInfo) -> None: ...
    def getKs(self) -> str: ...
    def getContext(self) -> KalturaAuditTrailContext: ...
    def getEntryPoint(self) -> str: ...
    def getServerName(self) -> str: ...
    def getIpAddress(self) -> str: ...
    def getUserAgent(self) -> str: ...
    def getClientTag(self) -> str: ...
    def setClientTag(self, newClientTag: str) -> None: ...
    def getDescription(self) -> str: ...
    def setDescription(self, newDescription: str) -> None: ...
    def getErrorDescription(self) -> str: ...

class KalturaAuditTrailChangeItem(KalturaObjectBase):
    descriptor: str
    oldValue: str
    newValue: str
    def __init__(self,
            descriptor: str = NotImplemented,
            oldValue: str = NotImplemented,
            newValue: str = NotImplemented): ...

    def getDescriptor(self) -> str: ...
    def setDescriptor(self, newDescriptor: str) -> None: ...
    def getOldValue(self) -> str: ...
    def setOldValue(self, newOldValue: str) -> None: ...
    def getNewValue(self) -> str: ...
    def setNewValue(self, newNewValue: str) -> None: ...

class KalturaAuditTrailChangeInfo(KalturaAuditTrailInfo):
    changedItems: List[KalturaAuditTrailChangeItem]
    def __init__(self,
            changedItems: List[KalturaAuditTrailChangeItem] = NotImplemented): ...

    def getChangedItems(self) -> List[KalturaAuditTrailChangeItem]: ...
    def setChangedItems(self, newChangedItems: List[KalturaAuditTrailChangeItem]) -> None: ...

class KalturaAuditTrailChangeXmlNode(KalturaAuditTrailChangeItem):
    type: KalturaAuditTrailChangeXmlNodeType
    def __init__(self,
            descriptor: str = NotImplemented,
            oldValue: str = NotImplemented,
            newValue: str = NotImplemented,
            type: KalturaAuditTrailChangeXmlNodeType = NotImplemented): ...

    def getType(self) -> KalturaAuditTrailChangeXmlNodeType: ...
    def setType(self, newType: KalturaAuditTrailChangeXmlNodeType) -> None: ...

class KalturaAuditTrailFileSyncCreateInfo(KalturaAuditTrailInfo):
    version: str
    objectSubType: int
    dc: int
    original: bool
    fileType: KalturaAuditTrailFileSyncType
    def __init__(self,
            version: str = NotImplemented,
            objectSubType: int = NotImplemented,
            dc: int = NotImplemented,
            original: bool = NotImplemented,
            fileType: KalturaAuditTrailFileSyncType = NotImplemented): ...

    def getVersion(self) -> str: ...
    def setVersion(self, newVersion: str) -> None: ...
    def getObjectSubType(self) -> int: ...
    def setObjectSubType(self, newObjectSubType: int) -> None: ...
    def getDc(self) -> int: ...
    def setDc(self, newDc: int) -> None: ...
    def getOriginal(self) -> bool: ...
    def setOriginal(self, newOriginal: bool) -> None: ...
    def getFileType(self) -> KalturaAuditTrailFileSyncType: ...
    def setFileType(self, newFileType: KalturaAuditTrailFileSyncType) -> None: ...

class KalturaAuditTrailListResponse(KalturaListResponse):
    objects: List[KalturaAuditTrail]
    def __init__(self,
            totalCount: int = NotImplemented,
            objects: List[KalturaAuditTrail] = NotImplemented): ...

    def getObjects(self) -> List[KalturaAuditTrail]: ...

class KalturaAuditTrailTextInfo(KalturaAuditTrailInfo):
    info: str
    def __init__(self,
            info: str = NotImplemented): ...

    def getInfo(self) -> str: ...
    def setInfo(self, newInfo: str) -> None: ...

class KalturaAuditTrailBaseFilter(KalturaRelatedFilter):
    idEqual: int
    createdAtGreaterThanOrEqual: int
    createdAtLessThanOrEqual: int
    parsedAtGreaterThanOrEqual: int
    parsedAtLessThanOrEqual: int
    statusEqual: KalturaAuditTrailStatus
    statusIn: str
    auditObjectTypeEqual: KalturaAuditTrailObjectType
    auditObjectTypeIn: str
    objectIdEqual: str
    objectIdIn: str
    relatedObjectIdEqual: str
    relatedObjectIdIn: str
    relatedObjectTypeEqual: KalturaAuditTrailObjectType
    relatedObjectTypeIn: str
    entryIdEqual: str
    entryIdIn: str
    masterPartnerIdEqual: int
    masterPartnerIdIn: str
    partnerIdEqual: int
    partnerIdIn: str
    requestIdEqual: str
    requestIdIn: str
    userIdEqual: str
    userIdIn: str
    actionEqual: KalturaAuditTrailAction
    actionIn: str
    ksEqual: str
    contextEqual: KalturaAuditTrailContext
    contextIn: str
    entryPointEqual: str
    entryPointIn: str
    serverNameEqual: str
    serverNameIn: str
    ipAddressEqual: str
    ipAddressIn: str
    clientTagEqual: str
    def __init__(self,
            orderBy: str = NotImplemented,
            advancedSearch: KalturaSearchItem = NotImplemented,
            idEqual: int = NotImplemented,
            createdAtGreaterThanOrEqual: int = NotImplemented,
            createdAtLessThanOrEqual: int = NotImplemented,
            parsedAtGreaterThanOrEqual: int = NotImplemented,
            parsedAtLessThanOrEqual: int = NotImplemented,
            statusEqual: KalturaAuditTrailStatus = NotImplemented,
            statusIn: str = NotImplemented,
            auditObjectTypeEqual: KalturaAuditTrailObjectType = NotImplemented,
            auditObjectTypeIn: str = NotImplemented,
            objectIdEqual: str = NotImplemented,
            objectIdIn: str = NotImplemented,
            relatedObjectIdEqual: str = NotImplemented,
            relatedObjectIdIn: str = NotImplemented,
            relatedObjectTypeEqual: KalturaAuditTrailObjectType = NotImplemented,
            relatedObjectTypeIn: str = NotImplemented,
            entryIdEqual: str = NotImplemented,
            entryIdIn: str = NotImplemented,
            masterPartnerIdEqual: int = NotImplemented,
            masterPartnerIdIn: str = NotImplemented,
            partnerIdEqual: int = NotImplemented,
            partnerIdIn: str = NotImplemented,
            requestIdEqual: str = NotImplemented,
            requestIdIn: str = NotImplemented,
            userIdEqual: str = NotImplemented,
            userIdIn: str = NotImplemented,
            actionEqual: KalturaAuditTrailAction = NotImplemented,
            actionIn: str = NotImplemented,
            ksEqual: str = NotImplemented,
            contextEqual: KalturaAuditTrailContext = NotImplemented,
            contextIn: str = NotImplemented,
            entryPointEqual: str = NotImplemented,
            entryPointIn: str = NotImplemented,
            serverNameEqual: str = NotImplemented,
            serverNameIn: str = NotImplemented,
            ipAddressEqual: str = NotImplemented,
            ipAddressIn: str = NotImplemented,
            clientTagEqual: str = NotImplemented): ...

    def getIdEqual(self) -> int: ...
    def setIdEqual(self, newIdEqual: int) -> None: ...
    def getCreatedAtGreaterThanOrEqual(self) -> int: ...
    def setCreatedAtGreaterThanOrEqual(self, newCreatedAtGreaterThanOrEqual: int) -> None: ...
    def getCreatedAtLessThanOrEqual(self) -> int: ...
    def setCreatedAtLessThanOrEqual(self, newCreatedAtLessThanOrEqual: int) -> None: ...
    def getParsedAtGreaterThanOrEqual(self) -> int: ...
    def setParsedAtGreaterThanOrEqual(self, newParsedAtGreaterThanOrEqual: int) -> None: ...
    def getParsedAtLessThanOrEqual(self) -> int: ...
    def setParsedAtLessThanOrEqual(self, newParsedAtLessThanOrEqual: int) -> None: ...
    def getStatusEqual(self) -> KalturaAuditTrailStatus: ...
    def setStatusEqual(self, newStatusEqual: KalturaAuditTrailStatus) -> None: ...
    def getStatusIn(self) -> str: ...
    def setStatusIn(self, newStatusIn: str) -> None: ...
    def getAuditObjectTypeEqual(self) -> KalturaAuditTrailObjectType: ...
    def setAuditObjectTypeEqual(self, newAuditObjectTypeEqual: KalturaAuditTrailObjectType) -> None: ...
    def getAuditObjectTypeIn(self) -> str: ...
    def setAuditObjectTypeIn(self, newAuditObjectTypeIn: str) -> None: ...
    def getObjectIdEqual(self) -> str: ...
    def setObjectIdEqual(self, newObjectIdEqual: str) -> None: ...
    def getObjectIdIn(self) -> str: ...
    def setObjectIdIn(self, newObjectIdIn: str) -> None: ...
    def getRelatedObjectIdEqual(self) -> str: ...
    def setRelatedObjectIdEqual(self, newRelatedObjectIdEqual: str) -> None: ...
    def getRelatedObjectIdIn(self) -> str: ...
    def setRelatedObjectIdIn(self, newRelatedObjectIdIn: str) -> None: ...
    def getRelatedObjectTypeEqual(self) -> KalturaAuditTrailObjectType: ...
    def setRelatedObjectTypeEqual(self, newRelatedObjectTypeEqual: KalturaAuditTrailObjectType) -> None: ...
    def getRelatedObjectTypeIn(self) -> str: ...
    def setRelatedObjectTypeIn(self, newRelatedObjectTypeIn: str) -> None: ...
    def getEntryIdEqual(self) -> str: ...
    def setEntryIdEqual(self, newEntryIdEqual: str) -> None: ...
    def getEntryIdIn(self) -> str: ...
    def setEntryIdIn(self, newEntryIdIn: str) -> None: ...
    def getMasterPartnerIdEqual(self) -> int: ...
    def setMasterPartnerIdEqual(self, newMasterPartnerIdEqual: int) -> None: ...
    def getMasterPartnerIdIn(self) -> str: ...
    def setMasterPartnerIdIn(self, newMasterPartnerIdIn: str) -> None: ...
    def getPartnerIdEqual(self) -> int: ...
    def setPartnerIdEqual(self, newPartnerIdEqual: int) -> None: ...
    def getPartnerIdIn(self) -> str: ...
    def setPartnerIdIn(self, newPartnerIdIn: str) -> None: ...
    def getRequestIdEqual(self) -> str: ...
    def setRequestIdEqual(self, newRequestIdEqual: str) -> None: ...
    def getRequestIdIn(self) -> str: ...
    def setRequestIdIn(self, newRequestIdIn: str) -> None: ...
    def getUserIdEqual(self) -> str: ...
    def setUserIdEqual(self, newUserIdEqual: str) -> None: ...
    def getUserIdIn(self) -> str: ...
    def setUserIdIn(self, newUserIdIn: str) -> None: ...
    def getActionEqual(self) -> KalturaAuditTrailAction: ...
    def setActionEqual(self, newActionEqual: KalturaAuditTrailAction) -> None: ...
    def getActionIn(self) -> str: ...
    def setActionIn(self, newActionIn: str) -> None: ...
    def getKsEqual(self) -> str: ...
    def setKsEqual(self, newKsEqual: str) -> None: ...
    def getContextEqual(self) -> KalturaAuditTrailContext: ...
    def setContextEqual(self, newContextEqual: KalturaAuditTrailContext) -> None: ...
    def getContextIn(self) -> str: ...
    def setContextIn(self, newContextIn: str) -> None: ...
    def getEntryPointEqual(self) -> str: ...
    def setEntryPointEqual(self, newEntryPointEqual: str) -> None: ...
    def getEntryPointIn(self) -> str: ...
    def setEntryPointIn(self, newEntryPointIn: str) -> None: ...
    def getServerNameEqual(self) -> str: ...
    def setServerNameEqual(self, newServerNameEqual: str) -> None: ...
    def getServerNameIn(self) -> str: ...
    def setServerNameIn(self, newServerNameIn: str) -> None: ...
    def getIpAddressEqual(self) -> str: ...
    def setIpAddressEqual(self, newIpAddressEqual: str) -> None: ...
    def getIpAddressIn(self) -> str: ...
    def setIpAddressIn(self, newIpAddressIn: str) -> None: ...
    def getClientTagEqual(self) -> str: ...
    def setClientTagEqual(self, newClientTagEqual: str) -> None: ...

class KalturaAuditTrailFilter(KalturaAuditTrailBaseFilter):
    def __init__(self,
            orderBy: str = NotImplemented,
            advancedSearch: KalturaSearchItem = NotImplemented,
            idEqual: int = NotImplemented,
            createdAtGreaterThanOrEqual: int = NotImplemented,
            createdAtLessThanOrEqual: int = NotImplemented,
            parsedAtGreaterThanOrEqual: int = NotImplemented,
            parsedAtLessThanOrEqual: int = NotImplemented,
            statusEqual: KalturaAuditTrailStatus = NotImplemented,
            statusIn: str = NotImplemented,
            auditObjectTypeEqual: KalturaAuditTrailObjectType = NotImplemented,
            auditObjectTypeIn: str = NotImplemented,
            objectIdEqual: str = NotImplemented,
            objectIdIn: str = NotImplemented,
            relatedObjectIdEqual: str = NotImplemented,
            relatedObjectIdIn: str = NotImplemented,
            relatedObjectTypeEqual: KalturaAuditTrailObjectType = NotImplemented,
            relatedObjectTypeIn: str = NotImplemented,
            entryIdEqual: str = NotImplemented,
            entryIdIn: str = NotImplemented,
            masterPartnerIdEqual: int = NotImplemented,
            masterPartnerIdIn: str = NotImplemented,
            partnerIdEqual: int = NotImplemented,
            partnerIdIn: str = NotImplemented,
            requestIdEqual: str = NotImplemented,
            requestIdIn: str = NotImplemented,
            userIdEqual: str = NotImplemented,
            userIdIn: str = NotImplemented,
            actionEqual: KalturaAuditTrailAction = NotImplemented,
            actionIn: str = NotImplemented,
            ksEqual: str = NotImplemented,
            contextEqual: KalturaAuditTrailContext = NotImplemented,
            contextIn: str = NotImplemented,
            entryPointEqual: str = NotImplemented,
            entryPointIn: str = NotImplemented,
            serverNameEqual: str = NotImplemented,
            serverNameIn: str = NotImplemented,
            ipAddressEqual: str = NotImplemented,
            ipAddressIn: str = NotImplemented,
            clientTagEqual: str = NotImplemented): ...
        pass

class KalturaAuditTrailService(KalturaServiceBase):
    def add(self, auditTrail: KalturaAuditTrail) -> KalturaAuditTrail: ...
    def get(self, id: int) -> KalturaAuditTrail: ...
    def list(self, filter: KalturaAuditTrailFilter = NotImplemented, pager: KalturaFilterPager = NotImplemented) -> KalturaAuditTrailListResponse: ...

class KalturaAuditClientPluginServicesProxy:
    auditTrail: KalturaAuditTrailService