# ===================================================================================================
#                           _  __     _ _
#                          | |/ /__ _| | |_ _  _ _ _ __ _
#                          | ' </ _` | |  _| || | '_/ _` |
#                          |_|\_\__,_|_|\__|\_,_|_| \__,_|
#
# This file is part of the Kaltura Collaborative Media Suite which allows users
# to do with audio, video, and animation what Wiki platforms allow them to do with
# text.
#
# Copyright (C) 2006-2023  Kaltura Inc.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http:#www.gnu.org/licenses/>.
#
# @ignore
# ===================================================================================================
from typing import List, IO, Any
from .Core import *
from KalturaClient.Base import KalturaObjectBase, KalturaServiceBase

class KalturaCaptionAssetStatus(object):
    ERROR = -1
    QUEUED = 0
    READY = 2
    DELETED = 3
    IMPORTING = 7
    EXPORTING = 9

    def __init__(self, value: int): ...

    def getValue(self) -> int: ...

class KalturaCaptionAssetOrderBy(object):
    CREATED_AT_ASC = "+createdAt"
    DELETED_AT_ASC = "+deletedAt"
    SIZE_ASC = "+size"
    UPDATED_AT_ASC = "+updatedAt"
    CREATED_AT_DESC = "-createdAt"
    DELETED_AT_DESC = "-deletedAt"
    SIZE_DESC = "-size"
    UPDATED_AT_DESC = "-updatedAt"

    def __init__(self, value: str): ...

    def getValue(self) -> str: ...

class KalturaCaptionAssetUsage(object):
    CAPTION = "0"
    EXTENDED_AUDIO_DESCRIPTION = "1"

    def __init__(self, value: str): ...

    def getValue(self) -> str: ...

class KalturaCaptionParamsOrderBy(object):

    def __init__(self, value: str): ...

    def getValue(self) -> str: ...

class KalturaCaptionSource(object):
    UNKNOWN = "0"
    ZOOM = "1"
    WEBEX = "2"

    def __init__(self, value: str): ...

    def getValue(self) -> str: ...

class KalturaCaptionType(object):
    SRT = "1"
    DFXP = "2"
    WEBVTT = "3"
    CAP = "4"
    SCC = "5"

    def __init__(self, value: str): ...

    def getValue(self) -> str: ...

class KalturaCaptionAsset(KalturaAsset):
    captionParamsId: int
    language: KalturaLanguage
    languageCode: KalturaLanguageCode
    isDefault: KalturaNullableBoolean
    label: str
    format: KalturaCaptionType
    source: KalturaCaptionSource
    status: KalturaCaptionAssetStatus
    parentId: str
    accuracy: int
    displayOnPlayer: bool
    associatedTranscriptIds: str
    usage: KalturaCaptionAssetUsage
    def __init__(self,
            id: str = NotImplemented,
            entryId: str = NotImplemented,
            partnerId: int = NotImplemented,
            version: int = NotImplemented,
            size: int = NotImplemented,
            tags: str = NotImplemented,
            fileExt: str = NotImplemented,
            createdAt: int = NotImplemented,
            updatedAt: int = NotImplemented,
            deletedAt: int = NotImplemented,
            description: str = NotImplemented,
            partnerData: str = NotImplemented,
            partnerDescription: str = NotImplemented,
            actualSourceAssetParamsIds: str = NotImplemented,
            sizeInBytes: int = NotImplemented,
            captionParamsId: int = NotImplemented,
            language: KalturaLanguage = NotImplemented,
            languageCode: KalturaLanguageCode = NotImplemented,
            isDefault: KalturaNullableBoolean = NotImplemented,
            label: str = NotImplemented,
            format: KalturaCaptionType = NotImplemented,
            source: KalturaCaptionSource = NotImplemented,
            status: KalturaCaptionAssetStatus = NotImplemented,
            parentId: str = NotImplemented,
            accuracy: int = NotImplemented,
            displayOnPlayer: bool = NotImplemented,
            associatedTranscriptIds: str = NotImplemented,
            usage: KalturaCaptionAssetUsage = NotImplemented): ...

    def getCaptionParamsId(self) -> int: ...
    def setCaptionParamsId(self, newCaptionParamsId: int) -> None: ...
    def getLanguage(self) -> KalturaLanguage: ...
    def setLanguage(self, newLanguage: KalturaLanguage) -> None: ...
    def getLanguageCode(self) -> KalturaLanguageCode: ...
    def getIsDefault(self) -> KalturaNullableBoolean: ...
    def setIsDefault(self, newIsDefault: KalturaNullableBoolean) -> None: ...
    def getLabel(self) -> str: ...
    def setLabel(self, newLabel: str) -> None: ...
    def getFormat(self) -> KalturaCaptionType: ...
    def setFormat(self, newFormat: KalturaCaptionType) -> None: ...
    def getSource(self) -> KalturaCaptionSource: ...
    def setSource(self, newSource: KalturaCaptionSource) -> None: ...
    def getStatus(self) -> KalturaCaptionAssetStatus: ...
    def getParentId(self) -> str: ...
    def setParentId(self, newParentId: str) -> None: ...
    def getAccuracy(self) -> int: ...
    def setAccuracy(self, newAccuracy: int) -> None: ...
    def getDisplayOnPlayer(self) -> bool: ...
    def setDisplayOnPlayer(self, newDisplayOnPlayer: bool) -> None: ...
    def getAssociatedTranscriptIds(self) -> str: ...
    def setAssociatedTranscriptIds(self, newAssociatedTranscriptIds: str) -> None: ...
    def getUsage(self) -> KalturaCaptionAssetUsage: ...
    def setUsage(self, newUsage: KalturaCaptionAssetUsage) -> None: ...

class KalturaCaptionParams(KalturaAssetParams):
    language: KalturaLanguage
    isDefault: KalturaNullableBoolean
    label: str
    format: KalturaCaptionType
    sourceParamsId: int
    def __init__(self,
            id: int = NotImplemented,
            partnerId: int = NotImplemented,
            name: str = NotImplemented,
            systemName: str = NotImplemented,
            description: str = NotImplemented,
            createdAt: int = NotImplemented,
            isSystemDefault: KalturaNullableBoolean = NotImplemented,
            tags: str = NotImplemented,
            requiredPermissions: List[KalturaString] = NotImplemented,
            sourceRemoteStorageProfileId: int = NotImplemented,
            remoteStorageProfileIds: int = NotImplemented,
            mediaParserType: KalturaMediaParserType = NotImplemented,
            sourceAssetParamsIds: str = NotImplemented,
            language: KalturaLanguage = NotImplemented,
            isDefault: KalturaNullableBoolean = NotImplemented,
            label: str = NotImplemented,
            format: KalturaCaptionType = NotImplemented,
            sourceParamsId: int = NotImplemented): ...

    def getLanguage(self) -> KalturaLanguage: ...
    def setLanguage(self, newLanguage: KalturaLanguage) -> None: ...
    def getIsDefault(self) -> KalturaNullableBoolean: ...
    def setIsDefault(self, newIsDefault: KalturaNullableBoolean) -> None: ...
    def getLabel(self) -> str: ...
    def setLabel(self, newLabel: str) -> None: ...
    def getFormat(self) -> KalturaCaptionType: ...
    def setFormat(self, newFormat: KalturaCaptionType) -> None: ...
    def getSourceParamsId(self) -> int: ...
    def setSourceParamsId(self, newSourceParamsId: int) -> None: ...

class KalturaCaptionPlaybackPluginData(KalturaObjectBase):
    label: str
    format: str
    language: str
    webVttUrl: str
    url: str
    isDefault: bool
    languageCode: str
    def __init__(self,
            label: str = NotImplemented,
            format: str = NotImplemented,
            language: str = NotImplemented,
            webVttUrl: str = NotImplemented,
            url: str = NotImplemented,
            isDefault: bool = NotImplemented,
            languageCode: str = NotImplemented): ...

    def getLabel(self) -> str: ...
    def setLabel(self, newLabel: str) -> None: ...
    def getFormat(self) -> str: ...
    def setFormat(self, newFormat: str) -> None: ...
    def getLanguage(self) -> str: ...
    def setLanguage(self, newLanguage: str) -> None: ...
    def getWebVttUrl(self) -> str: ...
    def setWebVttUrl(self, newWebVttUrl: str) -> None: ...
    def getUrl(self) -> str: ...
    def setUrl(self, newUrl: str) -> None: ...
    def getIsDefault(self) -> bool: ...
    def setIsDefault(self, newIsDefault: bool) -> None: ...
    def getLanguageCode(self) -> str: ...
    def setLanguageCode(self, newLanguageCode: str) -> None: ...

class KalturaCaptionAssetListResponse(KalturaListResponse):
    objects: List[KalturaCaptionAsset]
    def __init__(self,
            totalCount: int = NotImplemented,
            objects: List[KalturaCaptionAsset] = NotImplemented): ...

    def getObjects(self) -> List[KalturaCaptionAsset]: ...

class KalturaCaptionParamsListResponse(KalturaListResponse):
    objects: List[KalturaCaptionParams]
    def __init__(self,
            totalCount: int = NotImplemented,
            objects: List[KalturaCaptionParams] = NotImplemented): ...

    def getObjects(self) -> List[KalturaCaptionParams]: ...

class KalturaConvertCaptionAssetJobData(KalturaJobData):
    captionAssetId: str
    fileLocation: str
    fileEncryptionKey: str
    fromType: str
    toType: str
    def __init__(self,
            captionAssetId: str = NotImplemented,
            fileLocation: str = NotImplemented,
            fileEncryptionKey: str = NotImplemented,
            fromType: str = NotImplemented,
            toType: str = NotImplemented): ...

    def getCaptionAssetId(self) -> str: ...
    def setCaptionAssetId(self, newCaptionAssetId: str) -> None: ...
    def getFileLocation(self) -> str: ...
    def setFileLocation(self, newFileLocation: str) -> None: ...
    def getFileEncryptionKey(self) -> str: ...
    def setFileEncryptionKey(self, newFileEncryptionKey: str) -> None: ...
    def getFromType(self) -> str: ...
    def setFromType(self, newFromType: str) -> None: ...
    def getToType(self) -> str: ...
    def setToType(self, newToType: str) -> None: ...

class KalturaCopyCaptionsJobData(KalturaJobData):
    entryId: str
    clipsDescriptionArray: List[KalturaClipDescription]
    fullCopy: bool
    def __init__(self,
            entryId: str = NotImplemented,
            clipsDescriptionArray: List[KalturaClipDescription] = NotImplemented,
            fullCopy: bool = NotImplemented): ...

    def getEntryId(self) -> str: ...
    def setEntryId(self, newEntryId: str) -> None: ...
    def getClipsDescriptionArray(self) -> List[KalturaClipDescription]: ...
    def setClipsDescriptionArray(self, newClipsDescriptionArray: List[KalturaClipDescription]) -> None: ...
    def getFullCopy(self) -> bool: ...
    def setFullCopy(self, newFullCopy: bool) -> None: ...

class KalturaParseMultiLanguageCaptionAssetJobData(KalturaJobData):
    multiLanaguageCaptionAssetId: str
    entryId: str
    fileLocation: str
    fileEncryptionKey: str
    def __init__(self,
            multiLanaguageCaptionAssetId: str = NotImplemented,
            entryId: str = NotImplemented,
            fileLocation: str = NotImplemented,
            fileEncryptionKey: str = NotImplemented): ...

    def getMultiLanaguageCaptionAssetId(self) -> str: ...
    def setMultiLanaguageCaptionAssetId(self, newMultiLanaguageCaptionAssetId: str) -> None: ...
    def getEntryId(self) -> str: ...
    def setEntryId(self, newEntryId: str) -> None: ...
    def getFileLocation(self) -> str: ...
    def setFileLocation(self, newFileLocation: str) -> None: ...
    def getFileEncryptionKey(self) -> str: ...
    def setFileEncryptionKey(self, newFileEncryptionKey: str) -> None: ...

class KalturaCaptionAssetBaseFilter(KalturaAssetFilter):
    captionParamsIdEqual: int
    captionParamsIdIn: str
    formatEqual: KalturaCaptionType
    formatIn: str
    statusEqual: KalturaCaptionAssetStatus
    statusIn: str
    statusNotIn: str
    def __init__(self,
            orderBy: str = NotImplemented,
            advancedSearch: KalturaSearchItem = NotImplemented,
            idEqual: str = NotImplemented,
            idIn: str = NotImplemented,
            entryIdEqual: str = NotImplemented,
            entryIdIn: str = NotImplemented,
            partnerIdEqual: int = NotImplemented,
            partnerIdIn: str = NotImplemented,
            sizeGreaterThanOrEqual: int = NotImplemented,
            sizeLessThanOrEqual: int = NotImplemented,
            tagsLike: str = NotImplemented,
            tagsMultiLikeOr: str = NotImplemented,
            tagsMultiLikeAnd: str = NotImplemented,
            createdAtGreaterThanOrEqual: int = NotImplemented,
            createdAtLessThanOrEqual: int = NotImplemented,
            updatedAtGreaterThanOrEqual: int = NotImplemented,
            updatedAtLessThanOrEqual: int = NotImplemented,
            deletedAtGreaterThanOrEqual: int = NotImplemented,
            deletedAtLessThanOrEqual: int = NotImplemented,
            typeIn: str = NotImplemented,
            captionParamsIdEqual: int = NotImplemented,
            captionParamsIdIn: str = NotImplemented,
            formatEqual: KalturaCaptionType = NotImplemented,
            formatIn: str = NotImplemented,
            statusEqual: KalturaCaptionAssetStatus = NotImplemented,
            statusIn: str = NotImplemented,
            statusNotIn: str = NotImplemented): ...

    def getCaptionParamsIdEqual(self) -> int: ...
    def setCaptionParamsIdEqual(self, newCaptionParamsIdEqual: int) -> None: ...
    def getCaptionParamsIdIn(self) -> str: ...
    def setCaptionParamsIdIn(self, newCaptionParamsIdIn: str) -> None: ...
    def getFormatEqual(self) -> KalturaCaptionType: ...
    def setFormatEqual(self, newFormatEqual: KalturaCaptionType) -> None: ...
    def getFormatIn(self) -> str: ...
    def setFormatIn(self, newFormatIn: str) -> None: ...
    def getStatusEqual(self) -> KalturaCaptionAssetStatus: ...
    def setStatusEqual(self, newStatusEqual: KalturaCaptionAssetStatus) -> None: ...
    def getStatusIn(self) -> str: ...
    def setStatusIn(self, newStatusIn: str) -> None: ...
    def getStatusNotIn(self) -> str: ...
    def setStatusNotIn(self, newStatusNotIn: str) -> None: ...

class KalturaCaptionParamsBaseFilter(KalturaAssetParamsFilter):
    formatEqual: KalturaCaptionType
    formatIn: str
    def __init__(self,
            orderBy: str = NotImplemented,
            advancedSearch: KalturaSearchItem = NotImplemented,
            idEqual: int = NotImplemented,
            idIn: str = NotImplemented,
            systemNameEqual: str = NotImplemented,
            systemNameIn: str = NotImplemented,
            isSystemDefaultEqual: KalturaNullableBoolean = NotImplemented,
            tagsEqual: str = NotImplemented,
            formatEqual: KalturaCaptionType = NotImplemented,
            formatIn: str = NotImplemented): ...

    def getFormatEqual(self) -> KalturaCaptionType: ...
    def setFormatEqual(self, newFormatEqual: KalturaCaptionType) -> None: ...
    def getFormatIn(self) -> str: ...
    def setFormatIn(self, newFormatIn: str) -> None: ...

class KalturaCaptionAssetFilter(KalturaCaptionAssetBaseFilter):
    def __init__(self,
            orderBy: str = NotImplemented,
            advancedSearch: KalturaSearchItem = NotImplemented,
            idEqual: str = NotImplemented,
            idIn: str = NotImplemented,
            entryIdEqual: str = NotImplemented,
            entryIdIn: str = NotImplemented,
            partnerIdEqual: int = NotImplemented,
            partnerIdIn: str = NotImplemented,
            sizeGreaterThanOrEqual: int = NotImplemented,
            sizeLessThanOrEqual: int = NotImplemented,
            tagsLike: str = NotImplemented,
            tagsMultiLikeOr: str = NotImplemented,
            tagsMultiLikeAnd: str = NotImplemented,
            createdAtGreaterThanOrEqual: int = NotImplemented,
            createdAtLessThanOrEqual: int = NotImplemented,
            updatedAtGreaterThanOrEqual: int = NotImplemented,
            updatedAtLessThanOrEqual: int = NotImplemented,
            deletedAtGreaterThanOrEqual: int = NotImplemented,
            deletedAtLessThanOrEqual: int = NotImplemented,
            typeIn: str = NotImplemented,
            captionParamsIdEqual: int = NotImplemented,
            captionParamsIdIn: str = NotImplemented,
            formatEqual: KalturaCaptionType = NotImplemented,
            formatIn: str = NotImplemented,
            statusEqual: KalturaCaptionAssetStatus = NotImplemented,
            statusIn: str = NotImplemented,
            statusNotIn: str = NotImplemented): ...
        pass

class KalturaCaptionParamsFilter(KalturaCaptionParamsBaseFilter):
    def __init__(self,
            orderBy: str = NotImplemented,
            advancedSearch: KalturaSearchItem = NotImplemented,
            idEqual: int = NotImplemented,
            idIn: str = NotImplemented,
            systemNameEqual: str = NotImplemented,
            systemNameIn: str = NotImplemented,
            isSystemDefaultEqual: KalturaNullableBoolean = NotImplemented,
            tagsEqual: str = NotImplemented,
            formatEqual: KalturaCaptionType = NotImplemented,
            formatIn: str = NotImplemented): ...
        pass

class KalturaCaptionAssetService(KalturaServiceBase):
    def add(self, entryId: str, captionAsset: KalturaCaptionAsset) -> KalturaCaptionAsset: ...
    def delete(self, captionAssetId: str) -> None: ...
    def export(self, assetId: str, storageProfileId: int) -> KalturaFlavorAsset: ...
    def get(self, captionAssetId: str) -> KalturaCaptionAsset: ...
    def getRemotePaths(self, id: str) -> KalturaRemotePathListResponse: ...
    def getUrl(self, id: str, storageId: int = NotImplemented) -> str: ...
    def list(self, filter: KalturaAssetFilter = NotImplemented, pager: KalturaFilterPager = NotImplemented) -> KalturaCaptionAssetListResponse: ...
    def serve(self, captionAssetId: str) -> IO[Any]: ...
    def serveAsJson(self, captionAssetId: str) -> IO[Any]: ...
    def serveByEntryId(self, entryId: str, captionParamId: int = NotImplemented) -> IO[Any]: ...
    def serveWebVTT(self, captionAssetId: str, segmentDuration: int = 30, segmentIndex: int = NotImplemented, localTimestamp: int = 10000) -> IO[Any]: ...
    def setAsDefault(self, captionAssetId: str) -> None: ...
    def setContent(self, id: str, contentResource: KalturaContentResource) -> KalturaCaptionAsset: ...
    def update(self, id: str, captionAsset: KalturaCaptionAsset) -> KalturaCaptionAsset: ...

class KalturaCaptionParamsService(KalturaServiceBase):
    def add(self, captionParams: KalturaCaptionParams) -> KalturaCaptionParams: ...
    def delete(self, id: int) -> None: ...
    def get(self, id: int) -> KalturaCaptionParams: ...
    def list(self, filter: KalturaCaptionParamsFilter = NotImplemented, pager: KalturaFilterPager = NotImplemented) -> KalturaCaptionParamsListResponse: ...
    def update(self, id: int, captionParams: KalturaCaptionParams) -> KalturaCaptionParams: ...

class KalturaCaptionClientPluginServicesProxy:
    captionAsset: KalturaCaptionAssetService
    captionParams: KalturaCaptionParamsService