# ===================================================================================================
#                           _  __     _ _
#                          | |/ /__ _| | |_ _  _ _ _ __ _
#                          | ' </ _` | |  _| || | '_/ _` |
#                          |_|\_\__,_|_|\__|\_,_|_| \__,_|
#
# This file is part of the Kaltura Collaborative Media Suite which allows users
# to do with audio, video, and animation what Wiki platforms allow them to do with
# text.
#
# Copyright (C) 2006-2023  Kaltura Inc.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http:#www.gnu.org/licenses/>.
#
# @ignore
# ===================================================================================================
from typing import List, IO, Any
from .Core import *
from KalturaClient.Base import KalturaObjectBase, KalturaServiceBase

class KalturaCuePointStatus(object):
    READY = 1
    DELETED = 2
    HANDLED = 3
    PENDING = 4

    def __init__(self, value: int): ...

    def getValue(self) -> int: ...

class KalturaQuestionType(object):
    MULTIPLE_CHOICE_ANSWER = 1
    TRUE_FALSE = 2
    REFLECTION_POINT = 3
    MULTIPLE_ANSWER_QUESTION = 4
    FILL_IN_BLANK = 5
    HOT_SPOT = 6
    GO_TO = 7
    OPEN_QUESTION = 8

    def __init__(self, value: int): ...

    def getValue(self) -> int: ...

class KalturaQuizOutputType(object):
    PDF = 1

    def __init__(self, value: int): ...

    def getValue(self) -> int: ...

class KalturaScoreType(object):
    HIGHEST = 1
    LOWEST = 2
    LATEST = 3
    FIRST = 4
    AVERAGE = 5

    def __init__(self, value: int): ...

    def getValue(self) -> int: ...

class KalturaThumbCuePointSubType(object):
    SLIDE = 1
    CHAPTER = 2

    def __init__(self, value: int): ...

    def getValue(self) -> int: ...

class KalturaCuePointOrderBy(object):
    CREATED_AT_ASC = "+createdAt"
    INT_ID_ASC = "+intId"
    PARTNER_SORT_VALUE_ASC = "+partnerSortValue"
    START_TIME_ASC = "+startTime"
    TRIGGERED_AT_ASC = "+triggeredAt"
    UPDATED_AT_ASC = "+updatedAt"
    CREATED_AT_DESC = "-createdAt"
    INT_ID_DESC = "-intId"
    PARTNER_SORT_VALUE_DESC = "-partnerSortValue"
    START_TIME_DESC = "-startTime"
    TRIGGERED_AT_DESC = "-triggeredAt"
    UPDATED_AT_DESC = "-updatedAt"

    def __init__(self, value: str): ...

    def getValue(self) -> str: ...

class KalturaCuePointType(object):
    AD = "adCuePoint.Ad"
    ANNOTATION = "annotation.Annotation"
    CODE = "codeCuePoint.Code"
    EVENT = "eventCuePoint.Event"
    QUIZ_ANSWER = "quiz.QUIZ_ANSWER"
    QUIZ_QUESTION = "quiz.QUIZ_QUESTION"
    SESSION = "sessionCuePoint.Session"
    THUMB = "thumbCuePoint.Thumb"

    def __init__(self, value: str): ...

    def getValue(self) -> str: ...

class KalturaCuePoint(KalturaObjectBase):
    id: str
    intId: int
    cuePointType: KalturaCuePointType
    status: KalturaCuePointStatus
    entryId: str
    partnerId: int
    createdAt: int
    updatedAt: int
    triggeredAt: int
    tags: str
    startTime: int
    userId: str
    partnerData: str
    partnerSortValue: int
    forceStop: KalturaNullableBoolean
    thumbOffset: int
    systemName: str
    isMomentary: bool
    copiedFrom: str
    def __init__(self,
            id: str = NotImplemented,
            intId: int = NotImplemented,
            cuePointType: KalturaCuePointType = NotImplemented,
            status: KalturaCuePointStatus = NotImplemented,
            entryId: str = NotImplemented,
            partnerId: int = NotImplemented,
            createdAt: int = NotImplemented,
            updatedAt: int = NotImplemented,
            triggeredAt: int = NotImplemented,
            tags: str = NotImplemented,
            startTime: int = NotImplemented,
            userId: str = NotImplemented,
            partnerData: str = NotImplemented,
            partnerSortValue: int = NotImplemented,
            forceStop: KalturaNullableBoolean = NotImplemented,
            thumbOffset: int = NotImplemented,
            systemName: str = NotImplemented,
            isMomentary: bool = NotImplemented,
            copiedFrom: str = NotImplemented): ...

    def getId(self) -> str: ...
    def getIntId(self) -> int: ...
    def getCuePointType(self) -> KalturaCuePointType: ...
    def getStatus(self) -> KalturaCuePointStatus: ...
    def getEntryId(self) -> str: ...
    def setEntryId(self, newEntryId: str) -> None: ...
    def getPartnerId(self) -> int: ...
    def getCreatedAt(self) -> int: ...
    def getUpdatedAt(self) -> int: ...
    def getTriggeredAt(self) -> int: ...
    def setTriggeredAt(self, newTriggeredAt: int) -> None: ...
    def getTags(self) -> str: ...
    def setTags(self, newTags: str) -> None: ...
    def getStartTime(self) -> int: ...
    def setStartTime(self, newStartTime: int) -> None: ...
    def getUserId(self) -> str: ...
    def setUserId(self, newUserId: str) -> None: ...
    def getPartnerData(self) -> str: ...
    def setPartnerData(self, newPartnerData: str) -> None: ...
    def getPartnerSortValue(self) -> int: ...
    def setPartnerSortValue(self, newPartnerSortValue: int) -> None: ...
    def getForceStop(self) -> KalturaNullableBoolean: ...
    def setForceStop(self, newForceStop: KalturaNullableBoolean) -> None: ...
    def getThumbOffset(self) -> int: ...
    def setThumbOffset(self, newThumbOffset: int) -> None: ...
    def getSystemName(self) -> str: ...
    def setSystemName(self, newSystemName: str) -> None: ...
    def getIsMomentary(self) -> bool: ...
    def getCopiedFrom(self) -> str: ...

class KalturaCuePointListResponse(KalturaListResponse):
    objects: List[KalturaCuePoint]
    def __init__(self,
            totalCount: int = NotImplemented,
            objects: List[KalturaCuePoint] = NotImplemented): ...

    def getObjects(self) -> List[KalturaCuePoint]: ...

class KalturaCuePointBaseFilter(KalturaRelatedFilter):
    idEqual: str
    idIn: str
    cuePointTypeEqual: KalturaCuePointType
    cuePointTypeIn: str
    statusEqual: KalturaCuePointStatus
    statusIn: str
    entryIdEqual: str
    entryIdIn: str
    createdAtGreaterThanOrEqual: int
    createdAtLessThanOrEqual: int
    updatedAtGreaterThanOrEqual: int
    updatedAtLessThanOrEqual: int
    triggeredAtGreaterThanOrEqual: int
    triggeredAtLessThanOrEqual: int
    tagsLike: str
    tagsMultiLikeOr: str
    tagsMultiLikeAnd: str
    startTimeGreaterThanOrEqual: int
    startTimeLessThanOrEqual: int
    userIdEqual: str
    userIdIn: str
    partnerSortValueEqual: int
    partnerSortValueIn: str
    partnerSortValueGreaterThanOrEqual: int
    partnerSortValueLessThanOrEqual: int
    forceStopEqual: KalturaNullableBoolean
    systemNameEqual: str
    systemNameIn: str
    def __init__(self,
            orderBy: str = NotImplemented,
            advancedSearch: KalturaSearchItem = NotImplemented,
            idEqual: str = NotImplemented,
            idIn: str = NotImplemented,
            cuePointTypeEqual: KalturaCuePointType = NotImplemented,
            cuePointTypeIn: str = NotImplemented,
            statusEqual: KalturaCuePointStatus = NotImplemented,
            statusIn: str = NotImplemented,
            entryIdEqual: str = NotImplemented,
            entryIdIn: str = NotImplemented,
            createdAtGreaterThanOrEqual: int = NotImplemented,
            createdAtLessThanOrEqual: int = NotImplemented,
            updatedAtGreaterThanOrEqual: int = NotImplemented,
            updatedAtLessThanOrEqual: int = NotImplemented,
            triggeredAtGreaterThanOrEqual: int = NotImplemented,
            triggeredAtLessThanOrEqual: int = NotImplemented,
            tagsLike: str = NotImplemented,
            tagsMultiLikeOr: str = NotImplemented,
            tagsMultiLikeAnd: str = NotImplemented,
            startTimeGreaterThanOrEqual: int = NotImplemented,
            startTimeLessThanOrEqual: int = NotImplemented,
            userIdEqual: str = NotImplemented,
            userIdIn: str = NotImplemented,
            partnerSortValueEqual: int = NotImplemented,
            partnerSortValueIn: str = NotImplemented,
            partnerSortValueGreaterThanOrEqual: int = NotImplemented,
            partnerSortValueLessThanOrEqual: int = NotImplemented,
            forceStopEqual: KalturaNullableBoolean = NotImplemented,
            systemNameEqual: str = NotImplemented,
            systemNameIn: str = NotImplemented): ...

    def getIdEqual(self) -> str: ...
    def setIdEqual(self, newIdEqual: str) -> None: ...
    def getIdIn(self) -> str: ...
    def setIdIn(self, newIdIn: str) -> None: ...
    def getCuePointTypeEqual(self) -> KalturaCuePointType: ...
    def setCuePointTypeEqual(self, newCuePointTypeEqual: KalturaCuePointType) -> None: ...
    def getCuePointTypeIn(self) -> str: ...
    def setCuePointTypeIn(self, newCuePointTypeIn: str) -> None: ...
    def getStatusEqual(self) -> KalturaCuePointStatus: ...
    def setStatusEqual(self, newStatusEqual: KalturaCuePointStatus) -> None: ...
    def getStatusIn(self) -> str: ...
    def setStatusIn(self, newStatusIn: str) -> None: ...
    def getEntryIdEqual(self) -> str: ...
    def setEntryIdEqual(self, newEntryIdEqual: str) -> None: ...
    def getEntryIdIn(self) -> str: ...
    def setEntryIdIn(self, newEntryIdIn: str) -> None: ...
    def getCreatedAtGreaterThanOrEqual(self) -> int: ...
    def setCreatedAtGreaterThanOrEqual(self, newCreatedAtGreaterThanOrEqual: int) -> None: ...
    def getCreatedAtLessThanOrEqual(self) -> int: ...
    def setCreatedAtLessThanOrEqual(self, newCreatedAtLessThanOrEqual: int) -> None: ...
    def getUpdatedAtGreaterThanOrEqual(self) -> int: ...
    def setUpdatedAtGreaterThanOrEqual(self, newUpdatedAtGreaterThanOrEqual: int) -> None: ...
    def getUpdatedAtLessThanOrEqual(self) -> int: ...
    def setUpdatedAtLessThanOrEqual(self, newUpdatedAtLessThanOrEqual: int) -> None: ...
    def getTriggeredAtGreaterThanOrEqual(self) -> int: ...
    def setTriggeredAtGreaterThanOrEqual(self, newTriggeredAtGreaterThanOrEqual: int) -> None: ...
    def getTriggeredAtLessThanOrEqual(self) -> int: ...
    def setTriggeredAtLessThanOrEqual(self, newTriggeredAtLessThanOrEqual: int) -> None: ...
    def getTagsLike(self) -> str: ...
    def setTagsLike(self, newTagsLike: str) -> None: ...
    def getTagsMultiLikeOr(self) -> str: ...
    def setTagsMultiLikeOr(self, newTagsMultiLikeOr: str) -> None: ...
    def getTagsMultiLikeAnd(self) -> str: ...
    def setTagsMultiLikeAnd(self, newTagsMultiLikeAnd: str) -> None: ...
    def getStartTimeGreaterThanOrEqual(self) -> int: ...
    def setStartTimeGreaterThanOrEqual(self, newStartTimeGreaterThanOrEqual: int) -> None: ...
    def getStartTimeLessThanOrEqual(self) -> int: ...
    def setStartTimeLessThanOrEqual(self, newStartTimeLessThanOrEqual: int) -> None: ...
    def getUserIdEqual(self) -> str: ...
    def setUserIdEqual(self, newUserIdEqual: str) -> None: ...
    def getUserIdIn(self) -> str: ...
    def setUserIdIn(self, newUserIdIn: str) -> None: ...
    def getPartnerSortValueEqual(self) -> int: ...
    def setPartnerSortValueEqual(self, newPartnerSortValueEqual: int) -> None: ...
    def getPartnerSortValueIn(self) -> str: ...
    def setPartnerSortValueIn(self, newPartnerSortValueIn: str) -> None: ...
    def getPartnerSortValueGreaterThanOrEqual(self) -> int: ...
    def setPartnerSortValueGreaterThanOrEqual(self, newPartnerSortValueGreaterThanOrEqual: int) -> None: ...
    def getPartnerSortValueLessThanOrEqual(self) -> int: ...
    def setPartnerSortValueLessThanOrEqual(self, newPartnerSortValueLessThanOrEqual: int) -> None: ...
    def getForceStopEqual(self) -> KalturaNullableBoolean: ...
    def setForceStopEqual(self, newForceStopEqual: KalturaNullableBoolean) -> None: ...
    def getSystemNameEqual(self) -> str: ...
    def setSystemNameEqual(self, newSystemNameEqual: str) -> None: ...
    def getSystemNameIn(self) -> str: ...
    def setSystemNameIn(self, newSystemNameIn: str) -> None: ...

class KalturaCuePointFilter(KalturaCuePointBaseFilter):
    freeText: str
    userIdEqualCurrent: KalturaNullableBoolean
    userIdCurrent: KalturaNullableBoolean
    def __init__(self,
            orderBy: str = NotImplemented,
            advancedSearch: KalturaSearchItem = NotImplemented,
            idEqual: str = NotImplemented,
            idIn: str = NotImplemented,
            cuePointTypeEqual: KalturaCuePointType = NotImplemented,
            cuePointTypeIn: str = NotImplemented,
            statusEqual: KalturaCuePointStatus = NotImplemented,
            statusIn: str = NotImplemented,
            entryIdEqual: str = NotImplemented,
            entryIdIn: str = NotImplemented,
            createdAtGreaterThanOrEqual: int = NotImplemented,
            createdAtLessThanOrEqual: int = NotImplemented,
            updatedAtGreaterThanOrEqual: int = NotImplemented,
            updatedAtLessThanOrEqual: int = NotImplemented,
            triggeredAtGreaterThanOrEqual: int = NotImplemented,
            triggeredAtLessThanOrEqual: int = NotImplemented,
            tagsLike: str = NotImplemented,
            tagsMultiLikeOr: str = NotImplemented,
            tagsMultiLikeAnd: str = NotImplemented,
            startTimeGreaterThanOrEqual: int = NotImplemented,
            startTimeLessThanOrEqual: int = NotImplemented,
            userIdEqual: str = NotImplemented,
            userIdIn: str = NotImplemented,
            partnerSortValueEqual: int = NotImplemented,
            partnerSortValueIn: str = NotImplemented,
            partnerSortValueGreaterThanOrEqual: int = NotImplemented,
            partnerSortValueLessThanOrEqual: int = NotImplemented,
            forceStopEqual: KalturaNullableBoolean = NotImplemented,
            systemNameEqual: str = NotImplemented,
            systemNameIn: str = NotImplemented,
            freeText: str = NotImplemented,
            userIdEqualCurrent: KalturaNullableBoolean = NotImplemented,
            userIdCurrent: KalturaNullableBoolean = NotImplemented): ...

    def getFreeText(self) -> str: ...
    def setFreeText(self, newFreeText: str) -> None: ...
    def getUserIdEqualCurrent(self) -> KalturaNullableBoolean: ...
    def setUserIdEqualCurrent(self, newUserIdEqualCurrent: KalturaNullableBoolean) -> None: ...
    def getUserIdCurrent(self) -> KalturaNullableBoolean: ...
    def setUserIdCurrent(self, newUserIdCurrent: KalturaNullableBoolean) -> None: ...

class KalturaCuePointService(KalturaServiceBase):
    def add(self, cuePoint: KalturaCuePoint) -> KalturaCuePoint: ...
    def addFromBulk(self, fileData: IO[Any]) -> KalturaCuePointListResponse: ...
    def clone(self, id: str, entryId: str) -> KalturaCuePoint: ...
    def count(self, filter: KalturaCuePointFilter = NotImplemented) -> int: ...
    def delete(self, id: str) -> None: ...
    def get(self, id: str) -> KalturaCuePoint: ...
    def list(self, filter: KalturaCuePointFilter = NotImplemented, pager: KalturaFilterPager = NotImplemented) -> KalturaCuePointListResponse: ...
    def serveBulk(self, filter: KalturaCuePointFilter = NotImplemented, pager: KalturaFilterPager = NotImplemented) -> IO[Any]: ...
    def update(self, id: str, cuePoint: KalturaCuePoint) -> KalturaCuePoint: ...
    def updateCuePointsTimes(self, id: str, startTime: int, endTime: int = NotImplemented) -> KalturaCuePoint: ...
    def updateStatus(self, id: str, status: int) -> None: ...

class KalturaCuePointClientPluginServicesProxy:
    cuePoint: KalturaCuePointService