# ===================================================================================================
#                           _  __     _ _
#                          | |/ /__ _| | |_ _  _ _ _ __ _
#                          | ' </ _` | |  _| || | '_/ _` |
#                          |_|\_\__,_|_|\__|\_,_|_| \__,_|
#
# This file is part of the Kaltura Collaborative Media Suite which allows users
# to do with audio, video, and animation what Wiki platforms allow them to do with
# text.
#
# Copyright (C) 2006-2023  Kaltura Inc.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http:#www.gnu.org/licenses/>.
#
# @ignore
# ===================================================================================================
from typing import List, IO, Any
from .Core import *
from KalturaClient.Base import KalturaObjectBase, KalturaServiceBase

class KalturaFileSyncStatus(object):
    ERROR = -1
    PENDING = 1
    READY = 2
    DELETED = 3
    PURGED = 4

    def __init__(self, value: int): ...

    def getValue(self) -> int: ...

class KalturaFileSyncType(object):
    FILE = 1
    LINK = 2
    URL = 3

    def __init__(self, value: int): ...

    def getValue(self) -> int: ...

class KalturaFileSyncOrderBy(object):
    CREATED_AT_ASC = "+createdAt"
    FILE_SIZE_ASC = "+fileSize"
    READY_AT_ASC = "+readyAt"
    SYNC_TIME_ASC = "+syncTime"
    UPDATED_AT_ASC = "+updatedAt"
    VERSION_ASC = "+version"
    CREATED_AT_DESC = "-createdAt"
    FILE_SIZE_DESC = "-fileSize"
    READY_AT_DESC = "-readyAt"
    SYNC_TIME_DESC = "-syncTime"
    UPDATED_AT_DESC = "-updatedAt"
    VERSION_DESC = "-version"

    def __init__(self, value: str): ...

    def getValue(self) -> str: ...

class KalturaFileSync(KalturaObjectBase):
    id: int
    partnerId: int
    fileObjectType: KalturaFileSyncObjectType
    objectId: str
    version: str
    objectSubType: int
    dc: str
    original: int
    createdAt: int
    updatedAt: int
    readyAt: int
    syncTime: int
    status: KalturaFileSyncStatus
    fileType: KalturaFileSyncType
    linkedId: int
    linkCount: int
    fileRoot: str
    filePath: str
    fileSize: float
    fileUrl: str
    fileContent: str
    fileDiscSize: float
    isCurrentDc: bool
    isDir: bool
    originalId: int
    srcPath: str
    srcEncKey: str
    storageClass: str
    def __init__(self,
            id: int = NotImplemented,
            partnerId: int = NotImplemented,
            fileObjectType: KalturaFileSyncObjectType = NotImplemented,
            objectId: str = NotImplemented,
            version: str = NotImplemented,
            objectSubType: int = NotImplemented,
            dc: str = NotImplemented,
            original: int = NotImplemented,
            createdAt: int = NotImplemented,
            updatedAt: int = NotImplemented,
            readyAt: int = NotImplemented,
            syncTime: int = NotImplemented,
            status: KalturaFileSyncStatus = NotImplemented,
            fileType: KalturaFileSyncType = NotImplemented,
            linkedId: int = NotImplemented,
            linkCount: int = NotImplemented,
            fileRoot: str = NotImplemented,
            filePath: str = NotImplemented,
            fileSize: float = NotImplemented,
            fileUrl: str = NotImplemented,
            fileContent: str = NotImplemented,
            fileDiscSize: float = NotImplemented,
            isCurrentDc: bool = NotImplemented,
            isDir: bool = NotImplemented,
            originalId: int = NotImplemented,
            srcPath: str = NotImplemented,
            srcEncKey: str = NotImplemented,
            storageClass: str = NotImplemented): ...

    def getId(self) -> int: ...
    def getPartnerId(self) -> int: ...
    def getFileObjectType(self) -> KalturaFileSyncObjectType: ...
    def getObjectId(self) -> str: ...
    def getVersion(self) -> str: ...
    def getObjectSubType(self) -> int: ...
    def getDc(self) -> str: ...
    def getOriginal(self) -> int: ...
    def getCreatedAt(self) -> int: ...
    def getUpdatedAt(self) -> int: ...
    def getReadyAt(self) -> int: ...
    def getSyncTime(self) -> int: ...
    def getStatus(self) -> KalturaFileSyncStatus: ...
    def setStatus(self, newStatus: KalturaFileSyncStatus) -> None: ...
    def getFileType(self) -> KalturaFileSyncType: ...
    def getLinkedId(self) -> int: ...
    def getLinkCount(self) -> int: ...
    def getFileRoot(self) -> str: ...
    def setFileRoot(self, newFileRoot: str) -> None: ...
    def getFilePath(self) -> str: ...
    def setFilePath(self, newFilePath: str) -> None: ...
    def getFileSize(self) -> float: ...
    def getFileUrl(self) -> str: ...
    def getFileContent(self) -> str: ...
    def getFileDiscSize(self) -> float: ...
    def getIsCurrentDc(self) -> bool: ...
    def getIsDir(self) -> bool: ...
    def getOriginalId(self) -> int: ...
    def getSrcPath(self) -> str: ...
    def setSrcPath(self, newSrcPath: str) -> None: ...
    def getSrcEncKey(self) -> str: ...
    def setSrcEncKey(self, newSrcEncKey: str) -> None: ...
    def getStorageClass(self) -> str: ...
    def setStorageClass(self, newStorageClass: str) -> None: ...

class KalturaFileSyncBaseFilter(KalturaFilter):
    partnerIdEqual: int
    fileObjectTypeEqual: KalturaFileSyncObjectType
    fileObjectTypeIn: str
    objectIdEqual: str
    objectIdIn: str
    versionEqual: str
    versionIn: str
    objectSubTypeEqual: int
    objectSubTypeIn: str
    dcEqual: str
    dcIn: str
    originalEqual: int
    createdAtGreaterThanOrEqual: int
    createdAtLessThanOrEqual: int
    updatedAtGreaterThanOrEqual: int
    updatedAtLessThanOrEqual: int
    readyAtGreaterThanOrEqual: int
    readyAtLessThanOrEqual: int
    syncTimeGreaterThanOrEqual: int
    syncTimeLessThanOrEqual: int
    statusEqual: KalturaFileSyncStatus
    statusIn: str
    fileTypeEqual: KalturaFileSyncType
    fileTypeIn: str
    linkedIdEqual: int
    linkCountGreaterThanOrEqual: int
    linkCountLessThanOrEqual: int
    fileSizeGreaterThanOrEqual: float
    fileSizeLessThanOrEqual: float
    def __init__(self,
            orderBy: str = NotImplemented,
            advancedSearch: KalturaSearchItem = NotImplemented,
            partnerIdEqual: int = NotImplemented,
            fileObjectTypeEqual: KalturaFileSyncObjectType = NotImplemented,
            fileObjectTypeIn: str = NotImplemented,
            objectIdEqual: str = NotImplemented,
            objectIdIn: str = NotImplemented,
            versionEqual: str = NotImplemented,
            versionIn: str = NotImplemented,
            objectSubTypeEqual: int = NotImplemented,
            objectSubTypeIn: str = NotImplemented,
            dcEqual: str = NotImplemented,
            dcIn: str = NotImplemented,
            originalEqual: int = NotImplemented,
            createdAtGreaterThanOrEqual: int = NotImplemented,
            createdAtLessThanOrEqual: int = NotImplemented,
            updatedAtGreaterThanOrEqual: int = NotImplemented,
            updatedAtLessThanOrEqual: int = NotImplemented,
            readyAtGreaterThanOrEqual: int = NotImplemented,
            readyAtLessThanOrEqual: int = NotImplemented,
            syncTimeGreaterThanOrEqual: int = NotImplemented,
            syncTimeLessThanOrEqual: int = NotImplemented,
            statusEqual: KalturaFileSyncStatus = NotImplemented,
            statusIn: str = NotImplemented,
            fileTypeEqual: KalturaFileSyncType = NotImplemented,
            fileTypeIn: str = NotImplemented,
            linkedIdEqual: int = NotImplemented,
            linkCountGreaterThanOrEqual: int = NotImplemented,
            linkCountLessThanOrEqual: int = NotImplemented,
            fileSizeGreaterThanOrEqual: float = NotImplemented,
            fileSizeLessThanOrEqual: float = NotImplemented): ...

    def getPartnerIdEqual(self) -> int: ...
    def setPartnerIdEqual(self, newPartnerIdEqual: int) -> None: ...
    def getFileObjectTypeEqual(self) -> KalturaFileSyncObjectType: ...
    def setFileObjectTypeEqual(self, newFileObjectTypeEqual: KalturaFileSyncObjectType) -> None: ...
    def getFileObjectTypeIn(self) -> str: ...
    def setFileObjectTypeIn(self, newFileObjectTypeIn: str) -> None: ...
    def getObjectIdEqual(self) -> str: ...
    def setObjectIdEqual(self, newObjectIdEqual: str) -> None: ...
    def getObjectIdIn(self) -> str: ...
    def setObjectIdIn(self, newObjectIdIn: str) -> None: ...
    def getVersionEqual(self) -> str: ...
    def setVersionEqual(self, newVersionEqual: str) -> None: ...
    def getVersionIn(self) -> str: ...
    def setVersionIn(self, newVersionIn: str) -> None: ...
    def getObjectSubTypeEqual(self) -> int: ...
    def setObjectSubTypeEqual(self, newObjectSubTypeEqual: int) -> None: ...
    def getObjectSubTypeIn(self) -> str: ...
    def setObjectSubTypeIn(self, newObjectSubTypeIn: str) -> None: ...
    def getDcEqual(self) -> str: ...
    def setDcEqual(self, newDcEqual: str) -> None: ...
    def getDcIn(self) -> str: ...
    def setDcIn(self, newDcIn: str) -> None: ...
    def getOriginalEqual(self) -> int: ...
    def setOriginalEqual(self, newOriginalEqual: int) -> None: ...
    def getCreatedAtGreaterThanOrEqual(self) -> int: ...
    def setCreatedAtGreaterThanOrEqual(self, newCreatedAtGreaterThanOrEqual: int) -> None: ...
    def getCreatedAtLessThanOrEqual(self) -> int: ...
    def setCreatedAtLessThanOrEqual(self, newCreatedAtLessThanOrEqual: int) -> None: ...
    def getUpdatedAtGreaterThanOrEqual(self) -> int: ...
    def setUpdatedAtGreaterThanOrEqual(self, newUpdatedAtGreaterThanOrEqual: int) -> None: ...
    def getUpdatedAtLessThanOrEqual(self) -> int: ...
    def setUpdatedAtLessThanOrEqual(self, newUpdatedAtLessThanOrEqual: int) -> None: ...
    def getReadyAtGreaterThanOrEqual(self) -> int: ...
    def setReadyAtGreaterThanOrEqual(self, newReadyAtGreaterThanOrEqual: int) -> None: ...
    def getReadyAtLessThanOrEqual(self) -> int: ...
    def setReadyAtLessThanOrEqual(self, newReadyAtLessThanOrEqual: int) -> None: ...
    def getSyncTimeGreaterThanOrEqual(self) -> int: ...
    def setSyncTimeGreaterThanOrEqual(self, newSyncTimeGreaterThanOrEqual: int) -> None: ...
    def getSyncTimeLessThanOrEqual(self) -> int: ...
    def setSyncTimeLessThanOrEqual(self, newSyncTimeLessThanOrEqual: int) -> None: ...
    def getStatusEqual(self) -> KalturaFileSyncStatus: ...
    def setStatusEqual(self, newStatusEqual: KalturaFileSyncStatus) -> None: ...
    def getStatusIn(self) -> str: ...
    def setStatusIn(self, newStatusIn: str) -> None: ...
    def getFileTypeEqual(self) -> KalturaFileSyncType: ...
    def setFileTypeEqual(self, newFileTypeEqual: KalturaFileSyncType) -> None: ...
    def getFileTypeIn(self) -> str: ...
    def setFileTypeIn(self, newFileTypeIn: str) -> None: ...
    def getLinkedIdEqual(self) -> int: ...
    def setLinkedIdEqual(self, newLinkedIdEqual: int) -> None: ...
    def getLinkCountGreaterThanOrEqual(self) -> int: ...
    def setLinkCountGreaterThanOrEqual(self, newLinkCountGreaterThanOrEqual: int) -> None: ...
    def getLinkCountLessThanOrEqual(self) -> int: ...
    def setLinkCountLessThanOrEqual(self, newLinkCountLessThanOrEqual: int) -> None: ...
    def getFileSizeGreaterThanOrEqual(self) -> float: ...
    def setFileSizeGreaterThanOrEqual(self, newFileSizeGreaterThanOrEqual: float) -> None: ...
    def getFileSizeLessThanOrEqual(self) -> float: ...
    def setFileSizeLessThanOrEqual(self, newFileSizeLessThanOrEqual: float) -> None: ...

class KalturaFileSyncListResponse(KalturaListResponse):
    objects: List[KalturaFileSync]
    def __init__(self,
            totalCount: int = NotImplemented,
            objects: List[KalturaFileSync] = NotImplemented): ...

    def getObjects(self) -> List[KalturaFileSync]: ...

class KalturaFileSyncFilter(KalturaFileSyncBaseFilter):
    currentDc: KalturaNullableBoolean
    def __init__(self,
            orderBy: str = NotImplemented,
            advancedSearch: KalturaSearchItem = NotImplemented,
            partnerIdEqual: int = NotImplemented,
            fileObjectTypeEqual: KalturaFileSyncObjectType = NotImplemented,
            fileObjectTypeIn: str = NotImplemented,
            objectIdEqual: str = NotImplemented,
            objectIdIn: str = NotImplemented,
            versionEqual: str = NotImplemented,
            versionIn: str = NotImplemented,
            objectSubTypeEqual: int = NotImplemented,
            objectSubTypeIn: str = NotImplemented,
            dcEqual: str = NotImplemented,
            dcIn: str = NotImplemented,
            originalEqual: int = NotImplemented,
            createdAtGreaterThanOrEqual: int = NotImplemented,
            createdAtLessThanOrEqual: int = NotImplemented,
            updatedAtGreaterThanOrEqual: int = NotImplemented,
            updatedAtLessThanOrEqual: int = NotImplemented,
            readyAtGreaterThanOrEqual: int = NotImplemented,
            readyAtLessThanOrEqual: int = NotImplemented,
            syncTimeGreaterThanOrEqual: int = NotImplemented,
            syncTimeLessThanOrEqual: int = NotImplemented,
            statusEqual: KalturaFileSyncStatus = NotImplemented,
            statusIn: str = NotImplemented,
            fileTypeEqual: KalturaFileSyncType = NotImplemented,
            fileTypeIn: str = NotImplemented,
            linkedIdEqual: int = NotImplemented,
            linkCountGreaterThanOrEqual: int = NotImplemented,
            linkCountLessThanOrEqual: int = NotImplemented,
            fileSizeGreaterThanOrEqual: float = NotImplemented,
            fileSizeLessThanOrEqual: float = NotImplemented,
            currentDc: KalturaNullableBoolean = NotImplemented): ...

    def getCurrentDc(self) -> KalturaNullableBoolean: ...
    def setCurrentDc(self, newCurrentDc: KalturaNullableBoolean) -> None: ...

class KalturaFileSyncClientPluginServicesProxy: