# ===================================================================================================
#                           _  __     _ _
#                          | |/ /__ _| | |_ _  _ _ _ __ _
#                          | ' </ _` | |  _| || | '_/ _` |
#                          |_|\_\__,_|_|\__|\_,_|_| \__,_|
#
# This file is part of the Kaltura Collaborative Media Suite which allows users
# to do with audio, video, and animation what Wiki platforms allow them to do with
# text.
#
# Copyright (C) 2006-2023  Kaltura Inc.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http:#www.gnu.org/licenses/>.
#
# @ignore
# ===================================================================================================
from typing import List, IO, Any
from .Core import *
from .EventNotification import *
from KalturaClient.Base import KalturaObjectBase, KalturaServiceBase

class KalturaHttpNotificationAuthenticationMethod(object):
    ANYSAFE = -18
    ANY = -17
    BASIC = 1
    DIGEST = 2
    GSSNEGOTIATE = 4
    NTLM = 8

    def __init__(self, value: int): ...

    def getValue(self) -> int: ...

class KalturaHttpNotificationMethod(object):
    GET = 1
    POST = 2
    PUT = 3
    DELETE = 4

    def __init__(self, value: int): ...

    def getValue(self) -> int: ...

class KalturaHttpNotificationSslVersion(object):
    V2 = 2
    V3 = 3

    def __init__(self, value: int): ...

    def getValue(self) -> int: ...

class KalturaHttpNotificationCertificateType(object):
    DER = "DER"
    ENG = "ENG"
    PEM = "PEM"

    def __init__(self, value: str): ...

    def getValue(self) -> str: ...

class KalturaHttpNotificationSslKeyType(object):
    DER = "DER"
    ENG = "ENG"
    PEM = "PEM"

    def __init__(self, value: str): ...

    def getValue(self) -> str: ...

class KalturaHttpNotificationTemplateOrderBy(object):
    CREATED_AT_ASC = "+createdAt"
    ID_ASC = "+id"
    UPDATED_AT_ASC = "+updatedAt"
    CREATED_AT_DESC = "-createdAt"
    ID_DESC = "-id"
    UPDATED_AT_DESC = "-updatedAt"

    def __init__(self, value: str): ...

    def getValue(self) -> str: ...

class KalturaSecureHashingAlgo(object):
    SHA_1 = 1
    SHA_256 = 2
    SHA_512 = 3

    def __init__(self, value: int): ...

    def getValue(self) -> int: ...

class KalturaHttpNotification(KalturaObjectBase):
    object: KalturaObjectBase
    eventObjectType: KalturaEventNotificationEventObjectType
    eventNotificationJobId: int
    templateId: int
    templateName: str
    templateSystemName: str
    eventType: KalturaEventNotificationEventType
    def __init__(self,
            object: KalturaObjectBase = NotImplemented,
            eventObjectType: KalturaEventNotificationEventObjectType = NotImplemented,
            eventNotificationJobId: int = NotImplemented,
            templateId: int = NotImplemented,
            templateName: str = NotImplemented,
            templateSystemName: str = NotImplemented,
            eventType: KalturaEventNotificationEventType = NotImplemented): ...

    def getObject(self) -> KalturaObjectBase: ...
    def setObject(self, newObject: KalturaObjectBase) -> None: ...
    def getEventObjectType(self) -> KalturaEventNotificationEventObjectType: ...
    def setEventObjectType(self, newEventObjectType: KalturaEventNotificationEventObjectType) -> None: ...
    def getEventNotificationJobId(self) -> int: ...
    def setEventNotificationJobId(self, newEventNotificationJobId: int) -> None: ...
    def getTemplateId(self) -> int: ...
    def setTemplateId(self, newTemplateId: int) -> None: ...
    def getTemplateName(self) -> str: ...
    def setTemplateName(self, newTemplateName: str) -> None: ...
    def getTemplateSystemName(self) -> str: ...
    def setTemplateSystemName(self, newTemplateSystemName: str) -> None: ...
    def getEventType(self) -> KalturaEventNotificationEventType: ...
    def setEventType(self, newEventType: KalturaEventNotificationEventType) -> None: ...

class KalturaHttpNotificationData(KalturaObjectBase):
    def __init__(self): ...
        pass

class KalturaHttpNotificationDataFields(KalturaHttpNotificationData):
    def __init__(self): ...
        pass

class KalturaHttpNotificationDataText(KalturaHttpNotificationData):
    content: KalturaStringValue
    def __init__(self,
            content: KalturaStringValue = NotImplemented): ...

    def getContent(self) -> KalturaStringValue: ...
    def setContent(self, newContent: KalturaStringValue) -> None: ...

class KalturaHttpNotificationObjectData(KalturaHttpNotificationData):
    apiObjectType: str
    format: KalturaResponseType
    ignoreNull: bool
    code: str
    dataStringReplacements: List[KalturaKeyValue]
    def __init__(self,
            apiObjectType: str = NotImplemented,
            format: KalturaResponseType = NotImplemented,
            ignoreNull: bool = NotImplemented,
            code: str = NotImplemented,
            dataStringReplacements: List[KalturaKeyValue] = NotImplemented): ...

    def getApiObjectType(self) -> str: ...
    def setApiObjectType(self, newApiObjectType: str) -> None: ...
    def getFormat(self) -> KalturaResponseType: ...
    def setFormat(self, newFormat: KalturaResponseType) -> None: ...
    def getIgnoreNull(self) -> bool: ...
    def setIgnoreNull(self, newIgnoreNull: bool) -> None: ...
    def getCode(self) -> str: ...
    def setCode(self, newCode: str) -> None: ...
    def getDataStringReplacements(self) -> List[KalturaKeyValue]: ...
    def setDataStringReplacements(self, newDataStringReplacements: List[KalturaKeyValue]) -> None: ...

class KalturaHttpNotificationTemplate(KalturaEventNotificationTemplate):
    url: str
    method: KalturaHttpNotificationMethod
    data: KalturaHttpNotificationData
    timeout: int
    connectTimeout: int
    username: str
    password: str
    authenticationMethod: KalturaHttpNotificationAuthenticationMethod
    sslVersion: KalturaHttpNotificationSslVersion
    sslCertificate: str
    sslCertificateType: KalturaHttpNotificationCertificateType
    sslCertificatePassword: str
    sslEngine: str
    sslEngineDefault: str
    sslKeyType: KalturaHttpNotificationSslKeyType
    sslKey: str
    sslKeyPassword: str
    customHeaders: List[KalturaKeyValue]
    secureHashingAlgo: KalturaSecureHashingAlgo
    def __init__(self,
            id: int = NotImplemented,
            partnerId: int = NotImplemented,
            name: str = NotImplemented,
            systemName: str = NotImplemented,
            description: str = NotImplemented,
            type: KalturaEventNotificationTemplateType = NotImplemented,
            status: KalturaEventNotificationTemplateStatus = NotImplemented,
            createdAt: int = NotImplemented,
            updatedAt: int = NotImplemented,
            manualDispatchEnabled: bool = NotImplemented,
            automaticDispatchEnabled: bool = NotImplemented,
            eventType: KalturaEventNotificationEventType = NotImplemented,
            eventObjectType: KalturaEventNotificationEventObjectType = NotImplemented,
            eventConditions: List[KalturaCondition] = NotImplemented,
            contentParameters: List[KalturaEventNotificationParameter] = NotImplemented,
            userParameters: List[KalturaEventNotificationParameter] = NotImplemented,
            eventDelayedCondition: KalturaEventNotificationDelayedCondition = NotImplemented,
            url: str = NotImplemented,
            method: KalturaHttpNotificationMethod = NotImplemented,
            data: KalturaHttpNotificationData = NotImplemented,
            timeout: int = NotImplemented,
            connectTimeout: int = NotImplemented,
            username: str = NotImplemented,
            password: str = NotImplemented,
            authenticationMethod: KalturaHttpNotificationAuthenticationMethod = NotImplemented,
            sslVersion: KalturaHttpNotificationSslVersion = NotImplemented,
            sslCertificate: str = NotImplemented,
            sslCertificateType: KalturaHttpNotificationCertificateType = NotImplemented,
            sslCertificatePassword: str = NotImplemented,
            sslEngine: str = NotImplemented,
            sslEngineDefault: str = NotImplemented,
            sslKeyType: KalturaHttpNotificationSslKeyType = NotImplemented,
            sslKey: str = NotImplemented,
            sslKeyPassword: str = NotImplemented,
            customHeaders: List[KalturaKeyValue] = NotImplemented,
            secureHashingAlgo: KalturaSecureHashingAlgo = NotImplemented): ...

    def getUrl(self) -> str: ...
    def setUrl(self, newUrl: str) -> None: ...
    def getMethod(self) -> KalturaHttpNotificationMethod: ...
    def setMethod(self, newMethod: KalturaHttpNotificationMethod) -> None: ...
    def getData(self) -> KalturaHttpNotificationData: ...
    def setData(self, newData: KalturaHttpNotificationData) -> None: ...
    def getTimeout(self) -> int: ...
    def setTimeout(self, newTimeout: int) -> None: ...
    def getConnectTimeout(self) -> int: ...
    def setConnectTimeout(self, newConnectTimeout: int) -> None: ...
    def getUsername(self) -> str: ...
    def setUsername(self, newUsername: str) -> None: ...
    def getPassword(self) -> str: ...
    def setPassword(self, newPassword: str) -> None: ...
    def getAuthenticationMethod(self) -> KalturaHttpNotificationAuthenticationMethod: ...
    def setAuthenticationMethod(self, newAuthenticationMethod: KalturaHttpNotificationAuthenticationMethod) -> None: ...
    def getSslVersion(self) -> KalturaHttpNotificationSslVersion: ...
    def setSslVersion(self, newSslVersion: KalturaHttpNotificationSslVersion) -> None: ...
    def getSslCertificate(self) -> str: ...
    def setSslCertificate(self, newSslCertificate: str) -> None: ...
    def getSslCertificateType(self) -> KalturaHttpNotificationCertificateType: ...
    def setSslCertificateType(self, newSslCertificateType: KalturaHttpNotificationCertificateType) -> None: ...
    def getSslCertificatePassword(self) -> str: ...
    def setSslCertificatePassword(self, newSslCertificatePassword: str) -> None: ...
    def getSslEngine(self) -> str: ...
    def setSslEngine(self, newSslEngine: str) -> None: ...
    def getSslEngineDefault(self) -> str: ...
    def setSslEngineDefault(self, newSslEngineDefault: str) -> None: ...
    def getSslKeyType(self) -> KalturaHttpNotificationSslKeyType: ...
    def setSslKeyType(self, newSslKeyType: KalturaHttpNotificationSslKeyType) -> None: ...
    def getSslKey(self) -> str: ...
    def setSslKey(self, newSslKey: str) -> None: ...
    def getSslKeyPassword(self) -> str: ...
    def setSslKeyPassword(self, newSslKeyPassword: str) -> None: ...
    def getCustomHeaders(self) -> List[KalturaKeyValue]: ...
    def setCustomHeaders(self, newCustomHeaders: List[KalturaKeyValue]) -> None: ...
    def getSecureHashingAlgo(self) -> KalturaSecureHashingAlgo: ...
    def setSecureHashingAlgo(self, newSecureHashingAlgo: KalturaSecureHashingAlgo) -> None: ...

class KalturaHttpNotificationDispatchJobData(KalturaEventNotificationDispatchJobData):
    url: str
    method: KalturaHttpNotificationMethod
    contentType: str
    data: str
    timeout: int
    connectTimeout: int
    username: str
    password: str
    authenticationMethod: KalturaHttpNotificationAuthenticationMethod
    sslVersion: KalturaHttpNotificationSslVersion
    sslCertificate: str
    sslCertificateType: KalturaHttpNotificationCertificateType
    sslCertificatePassword: str
    sslEngine: str
    sslEngineDefault: str
    sslKeyType: KalturaHttpNotificationSslKeyType
    sslKey: str
    sslKeyPassword: str
    customHeaders: List[KalturaKeyValue]
    signSecret: str
    def __init__(self,
            templateId: int = NotImplemented,
            contentParameters: List[KalturaKeyValue] = NotImplemented,
            url: str = NotImplemented,
            method: KalturaHttpNotificationMethod = NotImplemented,
            contentType: str = NotImplemented,
            data: str = NotImplemented,
            timeout: int = NotImplemented,
            connectTimeout: int = NotImplemented,
            username: str = NotImplemented,
            password: str = NotImplemented,
            authenticationMethod: KalturaHttpNotificationAuthenticationMethod = NotImplemented,
            sslVersion: KalturaHttpNotificationSslVersion = NotImplemented,
            sslCertificate: str = NotImplemented,
            sslCertificateType: KalturaHttpNotificationCertificateType = NotImplemented,
            sslCertificatePassword: str = NotImplemented,
            sslEngine: str = NotImplemented,
            sslEngineDefault: str = NotImplemented,
            sslKeyType: KalturaHttpNotificationSslKeyType = NotImplemented,
            sslKey: str = NotImplemented,
            sslKeyPassword: str = NotImplemented,
            customHeaders: List[KalturaKeyValue] = NotImplemented,
            signSecret: str = NotImplemented): ...

    def getUrl(self) -> str: ...
    def setUrl(self, newUrl: str) -> None: ...
    def getMethod(self) -> KalturaHttpNotificationMethod: ...
    def setMethod(self, newMethod: KalturaHttpNotificationMethod) -> None: ...
    def getContentType(self) -> str: ...
    def setContentType(self, newContentType: str) -> None: ...
    def getData(self) -> str: ...
    def setData(self, newData: str) -> None: ...
    def getTimeout(self) -> int: ...
    def setTimeout(self, newTimeout: int) -> None: ...
    def getConnectTimeout(self) -> int: ...
    def setConnectTimeout(self, newConnectTimeout: int) -> None: ...
    def getUsername(self) -> str: ...
    def setUsername(self, newUsername: str) -> None: ...
    def getPassword(self) -> str: ...
    def setPassword(self, newPassword: str) -> None: ...
    def getAuthenticationMethod(self) -> KalturaHttpNotificationAuthenticationMethod: ...
    def setAuthenticationMethod(self, newAuthenticationMethod: KalturaHttpNotificationAuthenticationMethod) -> None: ...
    def getSslVersion(self) -> KalturaHttpNotificationSslVersion: ...
    def setSslVersion(self, newSslVersion: KalturaHttpNotificationSslVersion) -> None: ...
    def getSslCertificate(self) -> str: ...
    def setSslCertificate(self, newSslCertificate: str) -> None: ...
    def getSslCertificateType(self) -> KalturaHttpNotificationCertificateType: ...
    def setSslCertificateType(self, newSslCertificateType: KalturaHttpNotificationCertificateType) -> None: ...
    def getSslCertificatePassword(self) -> str: ...
    def setSslCertificatePassword(self, newSslCertificatePassword: str) -> None: ...
    def getSslEngine(self) -> str: ...
    def setSslEngine(self, newSslEngine: str) -> None: ...
    def getSslEngineDefault(self) -> str: ...
    def setSslEngineDefault(self, newSslEngineDefault: str) -> None: ...
    def getSslKeyType(self) -> KalturaHttpNotificationSslKeyType: ...
    def setSslKeyType(self, newSslKeyType: KalturaHttpNotificationSslKeyType) -> None: ...
    def getSslKey(self) -> str: ...
    def setSslKey(self, newSslKey: str) -> None: ...
    def getSslKeyPassword(self) -> str: ...
    def setSslKeyPassword(self, newSslKeyPassword: str) -> None: ...
    def getCustomHeaders(self) -> List[KalturaKeyValue]: ...
    def setCustomHeaders(self, newCustomHeaders: List[KalturaKeyValue]) -> None: ...
    def getSignSecret(self) -> str: ...
    def setSignSecret(self, newSignSecret: str) -> None: ...

class KalturaHttpNotificationTemplateBaseFilter(KalturaEventNotificationTemplateFilter):
    def __init__(self,
            orderBy: str = NotImplemented,
            advancedSearch: KalturaSearchItem = NotImplemented,
            idEqual: int = NotImplemented,
            idIn: str = NotImplemented,
            partnerIdEqual: int = NotImplemented,
            partnerIdIn: str = NotImplemented,
            systemNameEqual: str = NotImplemented,
            systemNameIn: str = NotImplemented,
            typeEqual: KalturaEventNotificationTemplateType = NotImplemented,
            typeIn: str = NotImplemented,
            statusEqual: KalturaEventNotificationTemplateStatus = NotImplemented,
            statusIn: str = NotImplemented,
            createdAtGreaterThanOrEqual: int = NotImplemented,
            createdAtLessThanOrEqual: int = NotImplemented,
            updatedAtGreaterThanOrEqual: int = NotImplemented,
            updatedAtLessThanOrEqual: int = NotImplemented): ...
        pass

class KalturaHttpNotificationTemplateFilter(KalturaHttpNotificationTemplateBaseFilter):
    def __init__(self,
            orderBy: str = NotImplemented,
            advancedSearch: KalturaSearchItem = NotImplemented,
            idEqual: int = NotImplemented,
            idIn: str = NotImplemented,
            partnerIdEqual: int = NotImplemented,
            partnerIdIn: str = NotImplemented,
            systemNameEqual: str = NotImplemented,
            systemNameIn: str = NotImplemented,
            typeEqual: KalturaEventNotificationTemplateType = NotImplemented,
            typeIn: str = NotImplemented,
            statusEqual: KalturaEventNotificationTemplateStatus = NotImplemented,
            statusIn: str = NotImplemented,
            createdAtGreaterThanOrEqual: int = NotImplemented,
            createdAtLessThanOrEqual: int = NotImplemented,
            updatedAtGreaterThanOrEqual: int = NotImplemented,
            updatedAtLessThanOrEqual: int = NotImplemented): ...
        pass

class KalturaHttpNotificationClientPluginServicesProxy: