# ===================================================================================================
#                           _  __     _ _
#                          | |/ /__ _| | |_ _  _ _ _ __ _
#                          | ' </ _` | |  _| || | '_/ _` |
#                          |_|\_\__,_|_|\__|\_,_|_| \__,_|
#
# This file is part of the Kaltura Collaborative Media Suite which allows users
# to do with audio, video, and animation what Wiki platforms allow them to do with
# text.
#
# Copyright (C) 2006-2023  Kaltura Inc.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http:#www.gnu.org/licenses/>.
#
# @ignore
# ===================================================================================================
from typing import List, IO, Any
from .Core import *
from KalturaClient.Base import KalturaObjectBase, KalturaServiceBase

class KalturaMetadataProfileCreateMode(object):
    API = 1
    KMC = 2
    APP = 3

    def __init__(self, value: int): ...

    def getValue(self) -> int: ...

class KalturaMetadataProfileStatus(object):
    ACTIVE = 1
    DEPRECATED = 2
    TRANSFORMING = 3

    def __init__(self, value: int): ...

    def getValue(self) -> int: ...

class KalturaMetadataStatus(object):
    VALID = 1
    INVALID = 2
    DELETED = 3

    def __init__(self, value: int): ...

    def getValue(self) -> int: ...

class KalturaMetadataObjectType(object):
    AD_CUE_POINT = "adCuePointMetadata.AdCuePoint"
    ANNOTATION = "annotationMetadata.Annotation"
    CODE_CUE_POINT = "codeCuePointMetadata.CodeCuePoint"
    ANSWER_CUE_POINT = "quiz.AnswerCuePoint"
    QUESTION_CUE_POINT = "quiz.QuestionCuePoint"
    THUMB_CUE_POINT = "thumbCuePointMetadata.thumbCuePoint"
    ENTRY = "1"
    CATEGORY = "2"
    USER = "3"
    PARTNER = "4"
    DYNAMIC_OBJECT = "5"
    USER_ENTRY = "6"

    def __init__(self, value: str): ...

    def getValue(self) -> str: ...

class KalturaMetadataOrderBy(object):
    CREATED_AT_ASC = "+createdAt"
    METADATA_PROFILE_VERSION_ASC = "+metadataProfileVersion"
    UPDATED_AT_ASC = "+updatedAt"
    VERSION_ASC = "+version"
    CREATED_AT_DESC = "-createdAt"
    METADATA_PROFILE_VERSION_DESC = "-metadataProfileVersion"
    UPDATED_AT_DESC = "-updatedAt"
    VERSION_DESC = "-version"

    def __init__(self, value: str): ...

    def getValue(self) -> str: ...

class KalturaMetadataProfileOrderBy(object):
    CREATED_AT_ASC = "+createdAt"
    UPDATED_AT_ASC = "+updatedAt"
    CREATED_AT_DESC = "-createdAt"
    UPDATED_AT_DESC = "-updatedAt"

    def __init__(self, value: str): ...

    def getValue(self) -> str: ...

class KalturaMetadata(KalturaObjectBase):
    id: int
    partnerId: int
    metadataProfileId: int
    metadataProfileVersion: int
    metadataObjectType: KalturaMetadataObjectType
    objectId: str
    version: int
    createdAt: int
    updatedAt: int
    status: KalturaMetadataStatus
    xml: str
    def __init__(self,
            id: int = NotImplemented,
            partnerId: int = NotImplemented,
            metadataProfileId: int = NotImplemented,
            metadataProfileVersion: int = NotImplemented,
            metadataObjectType: KalturaMetadataObjectType = NotImplemented,
            objectId: str = NotImplemented,
            version: int = NotImplemented,
            createdAt: int = NotImplemented,
            updatedAt: int = NotImplemented,
            status: KalturaMetadataStatus = NotImplemented,
            xml: str = NotImplemented): ...

    def getId(self) -> int: ...
    def getPartnerId(self) -> int: ...
    def getMetadataProfileId(self) -> int: ...
    def getMetadataProfileVersion(self) -> int: ...
    def getMetadataObjectType(self) -> KalturaMetadataObjectType: ...
    def getObjectId(self) -> str: ...
    def getVersion(self) -> int: ...
    def getCreatedAt(self) -> int: ...
    def getUpdatedAt(self) -> int: ...
    def getStatus(self) -> KalturaMetadataStatus: ...
    def getXml(self) -> str: ...

class KalturaMetadataProfile(KalturaObjectBase):
    id: int
    partnerId: int
    metadataObjectType: KalturaMetadataObjectType
    version: int
    name: str
    systemName: str
    description: str
    createdAt: int
    updatedAt: int
    status: KalturaMetadataProfileStatus
    xsd: str
    views: str
    xslt: str
    createMode: KalturaMetadataProfileCreateMode
    disableReIndexing: bool
    def __init__(self,
            id: int = NotImplemented,
            partnerId: int = NotImplemented,
            metadataObjectType: KalturaMetadataObjectType = NotImplemented,
            version: int = NotImplemented,
            name: str = NotImplemented,
            systemName: str = NotImplemented,
            description: str = NotImplemented,
            createdAt: int = NotImplemented,
            updatedAt: int = NotImplemented,
            status: KalturaMetadataProfileStatus = NotImplemented,
            xsd: str = NotImplemented,
            views: str = NotImplemented,
            xslt: str = NotImplemented,
            createMode: KalturaMetadataProfileCreateMode = NotImplemented,
            disableReIndexing: bool = NotImplemented): ...

    def getId(self) -> int: ...
    def getPartnerId(self) -> int: ...
    def getMetadataObjectType(self) -> KalturaMetadataObjectType: ...
    def setMetadataObjectType(self, newMetadataObjectType: KalturaMetadataObjectType) -> None: ...
    def getVersion(self) -> int: ...
    def getName(self) -> str: ...
    def setName(self, newName: str) -> None: ...
    def getSystemName(self) -> str: ...
    def setSystemName(self, newSystemName: str) -> None: ...
    def getDescription(self) -> str: ...
    def setDescription(self, newDescription: str) -> None: ...
    def getCreatedAt(self) -> int: ...
    def getUpdatedAt(self) -> int: ...
    def getStatus(self) -> KalturaMetadataProfileStatus: ...
    def getXsd(self) -> str: ...
    def getViews(self) -> str: ...
    def getXslt(self) -> str: ...
    def getCreateMode(self) -> KalturaMetadataProfileCreateMode: ...
    def setCreateMode(self, newCreateMode: KalturaMetadataProfileCreateMode) -> None: ...
    def getDisableReIndexing(self) -> bool: ...
    def setDisableReIndexing(self, newDisableReIndexing: bool) -> None: ...

class KalturaMetadataProfileField(KalturaObjectBase):
    id: int
    xPath: str
    key: str
    label: str
    def __init__(self,
            id: int = NotImplemented,
            xPath: str = NotImplemented,
            key: str = NotImplemented,
            label: str = NotImplemented): ...

    def getId(self) -> int: ...
    def getXPath(self) -> str: ...
    def getKey(self) -> str: ...
    def getLabel(self) -> str: ...

class KalturaImportMetadataJobData(KalturaJobData):
    srcFileUrl: str
    destFileLocalPath: str
    metadataId: int
    def __init__(self,
            srcFileUrl: str = NotImplemented,
            destFileLocalPath: str = NotImplemented,
            metadataId: int = NotImplemented): ...

    def getSrcFileUrl(self) -> str: ...
    def setSrcFileUrl(self, newSrcFileUrl: str) -> None: ...
    def getDestFileLocalPath(self) -> str: ...
    def setDestFileLocalPath(self, newDestFileLocalPath: str) -> None: ...
    def getMetadataId(self) -> int: ...
    def setMetadataId(self, newMetadataId: int) -> None: ...

class KalturaMetadataListResponse(KalturaListResponse):
    objects: List[KalturaMetadata]
    def __init__(self,
            totalCount: int = NotImplemented,
            objects: List[KalturaMetadata] = NotImplemented): ...

    def getObjects(self) -> List[KalturaMetadata]: ...

class KalturaMetadataProfileBaseFilter(KalturaFilter):
    idEqual: int
    partnerIdEqual: int
    metadataObjectTypeEqual: KalturaMetadataObjectType
    metadataObjectTypeIn: str
    versionEqual: int
    nameEqual: str
    systemNameEqual: str
    systemNameIn: str
    createdAtGreaterThanOrEqual: int
    createdAtLessThanOrEqual: int
    updatedAtGreaterThanOrEqual: int
    updatedAtLessThanOrEqual: int
    statusEqual: KalturaMetadataProfileStatus
    statusIn: str
    createModeEqual: KalturaMetadataProfileCreateMode
    createModeNotEqual: KalturaMetadataProfileCreateMode
    createModeIn: str
    createModeNotIn: str
    def __init__(self,
            orderBy: str = NotImplemented,
            advancedSearch: KalturaSearchItem = NotImplemented,
            idEqual: int = NotImplemented,
            partnerIdEqual: int = NotImplemented,
            metadataObjectTypeEqual: KalturaMetadataObjectType = NotImplemented,
            metadataObjectTypeIn: str = NotImplemented,
            versionEqual: int = NotImplemented,
            nameEqual: str = NotImplemented,
            systemNameEqual: str = NotImplemented,
            systemNameIn: str = NotImplemented,
            createdAtGreaterThanOrEqual: int = NotImplemented,
            createdAtLessThanOrEqual: int = NotImplemented,
            updatedAtGreaterThanOrEqual: int = NotImplemented,
            updatedAtLessThanOrEqual: int = NotImplemented,
            statusEqual: KalturaMetadataProfileStatus = NotImplemented,
            statusIn: str = NotImplemented,
            createModeEqual: KalturaMetadataProfileCreateMode = NotImplemented,
            createModeNotEqual: KalturaMetadataProfileCreateMode = NotImplemented,
            createModeIn: str = NotImplemented,
            createModeNotIn: str = NotImplemented): ...

    def getIdEqual(self) -> int: ...
    def setIdEqual(self, newIdEqual: int) -> None: ...
    def getPartnerIdEqual(self) -> int: ...
    def setPartnerIdEqual(self, newPartnerIdEqual: int) -> None: ...
    def getMetadataObjectTypeEqual(self) -> KalturaMetadataObjectType: ...
    def setMetadataObjectTypeEqual(self, newMetadataObjectTypeEqual: KalturaMetadataObjectType) -> None: ...
    def getMetadataObjectTypeIn(self) -> str: ...
    def setMetadataObjectTypeIn(self, newMetadataObjectTypeIn: str) -> None: ...
    def getVersionEqual(self) -> int: ...
    def setVersionEqual(self, newVersionEqual: int) -> None: ...
    def getNameEqual(self) -> str: ...
    def setNameEqual(self, newNameEqual: str) -> None: ...
    def getSystemNameEqual(self) -> str: ...
    def setSystemNameEqual(self, newSystemNameEqual: str) -> None: ...
    def getSystemNameIn(self) -> str: ...
    def setSystemNameIn(self, newSystemNameIn: str) -> None: ...
    def getCreatedAtGreaterThanOrEqual(self) -> int: ...
    def setCreatedAtGreaterThanOrEqual(self, newCreatedAtGreaterThanOrEqual: int) -> None: ...
    def getCreatedAtLessThanOrEqual(self) -> int: ...
    def setCreatedAtLessThanOrEqual(self, newCreatedAtLessThanOrEqual: int) -> None: ...
    def getUpdatedAtGreaterThanOrEqual(self) -> int: ...
    def setUpdatedAtGreaterThanOrEqual(self, newUpdatedAtGreaterThanOrEqual: int) -> None: ...
    def getUpdatedAtLessThanOrEqual(self) -> int: ...
    def setUpdatedAtLessThanOrEqual(self, newUpdatedAtLessThanOrEqual: int) -> None: ...
    def getStatusEqual(self) -> KalturaMetadataProfileStatus: ...
    def setStatusEqual(self, newStatusEqual: KalturaMetadataProfileStatus) -> None: ...
    def getStatusIn(self) -> str: ...
    def setStatusIn(self, newStatusIn: str) -> None: ...
    def getCreateModeEqual(self) -> KalturaMetadataProfileCreateMode: ...
    def setCreateModeEqual(self, newCreateModeEqual: KalturaMetadataProfileCreateMode) -> None: ...
    def getCreateModeNotEqual(self) -> KalturaMetadataProfileCreateMode: ...
    def setCreateModeNotEqual(self, newCreateModeNotEqual: KalturaMetadataProfileCreateMode) -> None: ...
    def getCreateModeIn(self) -> str: ...
    def setCreateModeIn(self, newCreateModeIn: str) -> None: ...
    def getCreateModeNotIn(self) -> str: ...
    def setCreateModeNotIn(self, newCreateModeNotIn: str) -> None: ...

class KalturaMetadataProfileFieldListResponse(KalturaListResponse):
    objects: List[KalturaMetadataProfileField]
    def __init__(self,
            totalCount: int = NotImplemented,
            objects: List[KalturaMetadataProfileField] = NotImplemented): ...

    def getObjects(self) -> List[KalturaMetadataProfileField]: ...

class KalturaMetadataProfileListResponse(KalturaListResponse):
    objects: List[KalturaMetadataProfile]
    def __init__(self,
            totalCount: int = NotImplemented,
            objects: List[KalturaMetadataProfile] = NotImplemented): ...

    def getObjects(self) -> List[KalturaMetadataProfile]: ...

class KalturaMetadataReplacementOptionsItem(KalturaPluginReplacementOptionsItem):
    shouldCopyMetadata: bool
    def __init__(self,
            shouldCopyMetadata: bool = NotImplemented): ...

    def getShouldCopyMetadata(self) -> bool: ...
    def setShouldCopyMetadata(self, newShouldCopyMetadata: bool) -> None: ...

class KalturaMetadataResponseProfileMapping(KalturaResponseProfileMapping):
    def __init__(self,
            parentProperty: str = NotImplemented,
            filterProperty: str = NotImplemented,
            allowNull: bool = NotImplemented): ...
        pass

class KalturaTransformMetadataJobData(KalturaJobData):
    srcXsl: KalturaFileContainer
    srcVersion: int
    destVersion: int
    destXsd: KalturaFileContainer
    metadataProfileId: int
    def __init__(self,
            srcXsl: KalturaFileContainer = NotImplemented,
            srcVersion: int = NotImplemented,
            destVersion: int = NotImplemented,
            destXsd: KalturaFileContainer = NotImplemented,
            metadataProfileId: int = NotImplemented): ...

    def getSrcXsl(self) -> KalturaFileContainer: ...
    def setSrcXsl(self, newSrcXsl: KalturaFileContainer) -> None: ...
    def getSrcVersion(self) -> int: ...
    def setSrcVersion(self, newSrcVersion: int) -> None: ...
    def getDestVersion(self) -> int: ...
    def setDestVersion(self, newDestVersion: int) -> None: ...
    def getDestXsd(self) -> KalturaFileContainer: ...
    def setDestXsd(self, newDestXsd: KalturaFileContainer) -> None: ...
    def getMetadataProfileId(self) -> int: ...
    def setMetadataProfileId(self, newMetadataProfileId: int) -> None: ...

class KalturaCompareMetadataCondition(KalturaCompareCondition):
    xPath: str
    profileId: int
    profileSystemName: str
    def __init__(self,
            type: KalturaConditionType = NotImplemented,
            description: str = NotImplemented,
            not_: bool = NotImplemented,
            value: KalturaIntegerValue = NotImplemented,
            comparison: KalturaSearchConditionComparison = NotImplemented,
            xPath: str = NotImplemented,
            profileId: int = NotImplemented,
            profileSystemName: str = NotImplemented): ...

    def getXPath(self) -> str: ...
    def setXPath(self, newXPath: str) -> None: ...
    def getProfileId(self) -> int: ...
    def setProfileId(self, newProfileId: int) -> None: ...
    def getProfileSystemName(self) -> str: ...
    def setProfileSystemName(self, newProfileSystemName: str) -> None: ...

class KalturaDynamicObjectSearchItem(KalturaSearchOperator):
    field: str
    def __init__(self,
            type: KalturaSearchOperatorType = NotImplemented,
            items: List[KalturaSearchItem] = NotImplemented,
            field: str = NotImplemented): ...

    def getField(self) -> str: ...
    def setField(self, newField: str) -> None: ...

class KalturaMatchMetadataCondition(KalturaMatchCondition):
    xPath: str
    profileId: int
    profileSystemName: str
    def __init__(self,
            type: KalturaConditionType = NotImplemented,
            description: str = NotImplemented,
            not_: bool = NotImplemented,
            values: List[KalturaStringValue] = NotImplemented,
            matchType: KalturaMatchConditionType = NotImplemented,
            xPath: str = NotImplemented,
            profileId: int = NotImplemented,
            profileSystemName: str = NotImplemented): ...

    def getXPath(self) -> str: ...
    def setXPath(self, newXPath: str) -> None: ...
    def getProfileId(self) -> int: ...
    def setProfileId(self, newProfileId: int) -> None: ...
    def getProfileSystemName(self) -> str: ...
    def setProfileSystemName(self, newProfileSystemName: str) -> None: ...

class KalturaMetadataBaseFilter(KalturaRelatedFilter):
    partnerIdEqual: int
    metadataProfileIdEqual: int
    metadataProfileIdIn: str
    metadataProfileVersionEqual: int
    metadataProfileVersionGreaterThanOrEqual: int
    metadataProfileVersionLessThanOrEqual: int
    metadataObjectTypeEqual: KalturaMetadataObjectType
    objectIdEqual: str
    objectIdIn: str
    versionEqual: int
    versionGreaterThanOrEqual: int
    versionLessThanOrEqual: int
    createdAtGreaterThanOrEqual: int
    createdAtLessThanOrEqual: int
    updatedAtGreaterThanOrEqual: int
    updatedAtLessThanOrEqual: int
    statusEqual: KalturaMetadataStatus
    statusIn: str
    def __init__(self,
            orderBy: str = NotImplemented,
            advancedSearch: KalturaSearchItem = NotImplemented,
            partnerIdEqual: int = NotImplemented,
            metadataProfileIdEqual: int = NotImplemented,
            metadataProfileIdIn: str = NotImplemented,
            metadataProfileVersionEqual: int = NotImplemented,
            metadataProfileVersionGreaterThanOrEqual: int = NotImplemented,
            metadataProfileVersionLessThanOrEqual: int = NotImplemented,
            metadataObjectTypeEqual: KalturaMetadataObjectType = NotImplemented,
            objectIdEqual: str = NotImplemented,
            objectIdIn: str = NotImplemented,
            versionEqual: int = NotImplemented,
            versionGreaterThanOrEqual: int = NotImplemented,
            versionLessThanOrEqual: int = NotImplemented,
            createdAtGreaterThanOrEqual: int = NotImplemented,
            createdAtLessThanOrEqual: int = NotImplemented,
            updatedAtGreaterThanOrEqual: int = NotImplemented,
            updatedAtLessThanOrEqual: int = NotImplemented,
            statusEqual: KalturaMetadataStatus = NotImplemented,
            statusIn: str = NotImplemented): ...

    def getPartnerIdEqual(self) -> int: ...
    def setPartnerIdEqual(self, newPartnerIdEqual: int) -> None: ...
    def getMetadataProfileIdEqual(self) -> int: ...
    def setMetadataProfileIdEqual(self, newMetadataProfileIdEqual: int) -> None: ...
    def getMetadataProfileIdIn(self) -> str: ...
    def setMetadataProfileIdIn(self, newMetadataProfileIdIn: str) -> None: ...
    def getMetadataProfileVersionEqual(self) -> int: ...
    def setMetadataProfileVersionEqual(self, newMetadataProfileVersionEqual: int) -> None: ...
    def getMetadataProfileVersionGreaterThanOrEqual(self) -> int: ...
    def setMetadataProfileVersionGreaterThanOrEqual(self, newMetadataProfileVersionGreaterThanOrEqual: int) -> None: ...
    def getMetadataProfileVersionLessThanOrEqual(self) -> int: ...
    def setMetadataProfileVersionLessThanOrEqual(self, newMetadataProfileVersionLessThanOrEqual: int) -> None: ...
    def getMetadataObjectTypeEqual(self) -> KalturaMetadataObjectType: ...
    def setMetadataObjectTypeEqual(self, newMetadataObjectTypeEqual: KalturaMetadataObjectType) -> None: ...
    def getObjectIdEqual(self) -> str: ...
    def setObjectIdEqual(self, newObjectIdEqual: str) -> None: ...
    def getObjectIdIn(self) -> str: ...
    def setObjectIdIn(self, newObjectIdIn: str) -> None: ...
    def getVersionEqual(self) -> int: ...
    def setVersionEqual(self, newVersionEqual: int) -> None: ...
    def getVersionGreaterThanOrEqual(self) -> int: ...
    def setVersionGreaterThanOrEqual(self, newVersionGreaterThanOrEqual: int) -> None: ...
    def getVersionLessThanOrEqual(self) -> int: ...
    def setVersionLessThanOrEqual(self, newVersionLessThanOrEqual: int) -> None: ...
    def getCreatedAtGreaterThanOrEqual(self) -> int: ...
    def setCreatedAtGreaterThanOrEqual(self, newCreatedAtGreaterThanOrEqual: int) -> None: ...
    def getCreatedAtLessThanOrEqual(self) -> int: ...
    def setCreatedAtLessThanOrEqual(self, newCreatedAtLessThanOrEqual: int) -> None: ...
    def getUpdatedAtGreaterThanOrEqual(self) -> int: ...
    def setUpdatedAtGreaterThanOrEqual(self, newUpdatedAtGreaterThanOrEqual: int) -> None: ...
    def getUpdatedAtLessThanOrEqual(self) -> int: ...
    def setUpdatedAtLessThanOrEqual(self, newUpdatedAtLessThanOrEqual: int) -> None: ...
    def getStatusEqual(self) -> KalturaMetadataStatus: ...
    def setStatusEqual(self, newStatusEqual: KalturaMetadataStatus) -> None: ...
    def getStatusIn(self) -> str: ...
    def setStatusIn(self, newStatusIn: str) -> None: ...

class KalturaMetadataFieldChangedCondition(KalturaMatchCondition):
    xPath: str
    profileId: int
    profileSystemName: str
    versionA: str
    versionB: str
    def __init__(self,
            type: KalturaConditionType = NotImplemented,
            description: str = NotImplemented,
            not_: bool = NotImplemented,
            values: List[KalturaStringValue] = NotImplemented,
            matchType: KalturaMatchConditionType = NotImplemented,
            xPath: str = NotImplemented,
            profileId: int = NotImplemented,
            profileSystemName: str = NotImplemented,
            versionA: str = NotImplemented,
            versionB: str = NotImplemented): ...

    def getXPath(self) -> str: ...
    def setXPath(self, newXPath: str) -> None: ...
    def getProfileId(self) -> int: ...
    def setProfileId(self, newProfileId: int) -> None: ...
    def getProfileSystemName(self) -> str: ...
    def setProfileSystemName(self, newProfileSystemName: str) -> None: ...
    def getVersionA(self) -> str: ...
    def setVersionA(self, newVersionA: str) -> None: ...
    def getVersionB(self) -> str: ...
    def setVersionB(self, newVersionB: str) -> None: ...

class KalturaMetadataProfileFilter(KalturaMetadataProfileBaseFilter):
    def __init__(self,
            orderBy: str = NotImplemented,
            advancedSearch: KalturaSearchItem = NotImplemented,
            idEqual: int = NotImplemented,
            partnerIdEqual: int = NotImplemented,
            metadataObjectTypeEqual: KalturaMetadataObjectType = NotImplemented,
            metadataObjectTypeIn: str = NotImplemented,
            versionEqual: int = NotImplemented,
            nameEqual: str = NotImplemented,
            systemNameEqual: str = NotImplemented,
            systemNameIn: str = NotImplemented,
            createdAtGreaterThanOrEqual: int = NotImplemented,
            createdAtLessThanOrEqual: int = NotImplemented,
            updatedAtGreaterThanOrEqual: int = NotImplemented,
            updatedAtLessThanOrEqual: int = NotImplemented,
            statusEqual: KalturaMetadataProfileStatus = NotImplemented,
            statusIn: str = NotImplemented,
            createModeEqual: KalturaMetadataProfileCreateMode = NotImplemented,
            createModeNotEqual: KalturaMetadataProfileCreateMode = NotImplemented,
            createModeIn: str = NotImplemented,
            createModeNotIn: str = NotImplemented): ...
        pass

class KalturaMetadataSearchItem(KalturaSearchOperator):
    metadataProfileId: int
    orderBy: str
    def __init__(self,
            type: KalturaSearchOperatorType = NotImplemented,
            items: List[KalturaSearchItem] = NotImplemented,
            metadataProfileId: int = NotImplemented,
            orderBy: str = NotImplemented): ...

    def getMetadataProfileId(self) -> int: ...
    def setMetadataProfileId(self, newMetadataProfileId: int) -> None: ...
    def getOrderBy(self) -> str: ...
    def setOrderBy(self, newOrderBy: str) -> None: ...

class KalturaMetadataField(KalturaStringField):
    xPath: str
    profileId: int
    profileSystemName: str
    def __init__(self,
            description: str = NotImplemented,
            value: str = NotImplemented,
            xPath: str = NotImplemented,
            profileId: int = NotImplemented,
            profileSystemName: str = NotImplemented): ...

    def getXPath(self) -> str: ...
    def setXPath(self, newXPath: str) -> None: ...
    def getProfileId(self) -> int: ...
    def setProfileId(self, newProfileId: int) -> None: ...
    def getProfileSystemName(self) -> str: ...
    def setProfileSystemName(self, newProfileSystemName: str) -> None: ...

class KalturaMetadataFilter(KalturaMetadataBaseFilter):
    def __init__(self,
            orderBy: str = NotImplemented,
            advancedSearch: KalturaSearchItem = NotImplemented,
            partnerIdEqual: int = NotImplemented,
            metadataProfileIdEqual: int = NotImplemented,
            metadataProfileIdIn: str = NotImplemented,
            metadataProfileVersionEqual: int = NotImplemented,
            metadataProfileVersionGreaterThanOrEqual: int = NotImplemented,
            metadataProfileVersionLessThanOrEqual: int = NotImplemented,
            metadataObjectTypeEqual: KalturaMetadataObjectType = NotImplemented,
            objectIdEqual: str = NotImplemented,
            objectIdIn: str = NotImplemented,
            versionEqual: int = NotImplemented,
            versionGreaterThanOrEqual: int = NotImplemented,
            versionLessThanOrEqual: int = NotImplemented,
            createdAtGreaterThanOrEqual: int = NotImplemented,
            createdAtLessThanOrEqual: int = NotImplemented,
            updatedAtGreaterThanOrEqual: int = NotImplemented,
            updatedAtLessThanOrEqual: int = NotImplemented,
            statusEqual: KalturaMetadataStatus = NotImplemented,
            statusIn: str = NotImplemented): ...
        pass

class KalturaMetadataService(KalturaServiceBase):
    def add(self, metadataProfileId: int, objectType: str, objectId: str, xmlData: str) -> KalturaMetadata: ...
    def addFromBulk(self, metadataProfileId: int, objectType: str, objectId: str, url: str) -> KalturaMetadata: ...
    def addFromFile(self, metadataProfileId: int, objectType: str, objectId: str, xmlFile: IO[Any]) -> KalturaMetadata: ...
    def addFromUrl(self, metadataProfileId: int, objectType: str, objectId: str, url: str) -> KalturaMetadata: ...
    def delete(self, id: int) -> None: ...
    def get(self, id: int) -> KalturaMetadata: ...
    def index(self, id: str, shouldUpdate: bool) -> int: ...
    def invalidate(self, id: int, version: int = NotImplemented) -> None: ...
    def list(self, filter: KalturaMetadataFilter = NotImplemented, pager: KalturaFilterPager = NotImplemented) -> KalturaMetadataListResponse: ...
    def serve(self, id: int) -> IO[Any]: ...
    def update(self, id: int, xmlData: str = NotImplemented, version: int = NotImplemented) -> KalturaMetadata: ...
    def updateFromFile(self, id: int, xmlFile: IO[Any] = NotImplemented) -> KalturaMetadata: ...
    def updateFromXSL(self, id: int, xslFile: IO[Any]) -> KalturaMetadata: ...

class KalturaMetadataProfileService(KalturaServiceBase):
    def add(self, metadataProfile: KalturaMetadataProfile, xsdData: str, viewsData: str = NotImplemented) -> KalturaMetadataProfile: ...
    def addFromFile(self, metadataProfile: KalturaMetadataProfile, xsdFile: IO[Any], viewsFile: IO[Any] = NotImplemented) -> KalturaMetadataProfile: ...
    def delete(self, id: int) -> None: ...
    def get(self, id: int) -> KalturaMetadataProfile: ...
    def list(self, filter: KalturaMetadataProfileFilter = NotImplemented, pager: KalturaFilterPager = NotImplemented) -> KalturaMetadataProfileListResponse: ...
    def listFields(self, metadataProfileId: int) -> KalturaMetadataProfileFieldListResponse: ...
    def revert(self, id: int, toVersion: int) -> KalturaMetadataProfile: ...
    def serve(self, id: int) -> IO[Any]: ...
    def serveView(self, id: int) -> IO[Any]: ...
    def update(self, id: int, metadataProfile: KalturaMetadataProfile, xsdData: str = NotImplemented, viewsData: str = NotImplemented) -> KalturaMetadataProfile: ...
    def updateDefinitionFromFile(self, id: int, xsdFile: IO[Any]) -> KalturaMetadataProfile: ...
    def updateTransformationFromFile(self, id: int, xsltFile: IO[Any]) -> KalturaMetadataProfile: ...
    def updateViewsFromFile(self, id: int, viewsFile: IO[Any]) -> KalturaMetadataProfile: ...

class KalturaMetadataClientPluginServicesProxy:
    metadata: KalturaMetadataService
    metadataProfile: KalturaMetadataProfileService